<?php
	/*======
	*
	* Theme After Setup Start
	*
	======*/
	function bianco_setup(){
		load_theme_textdomain( 'bianco', get_template_directory() . '/languages' );
		add_theme_support( 'automatic-feed-links' );
		add_theme_support( 'title-tag' );
		add_theme_support( 'custom-background' );
		add_theme_support( 'custom-header' );
		add_theme_support( 'post-thumbnails' );
		add_theme_support( 'post-formats', array( 'quote', 'gallery', 'image', 'video', 'audio', 'chat', 'link' ) );
		add_theme_support( 'wc-product-gallery-zoom' );
		add_theme_support( 'wc-product-gallery-lightbox' );
		add_theme_support( 'wc-product-gallery-slider' );

		function bianco_add_editor_styles() {
			add_editor_style( 'custom-editor-style.css' );
		}
		add_action( 'admin_init', 'bianco_add_editor_styles' );

		if( function_exists( 'add_image_size' ) ) { 
			add_image_size( 'bianco-post-1', 540, 625, true );
			add_image_size( 'bianco-post-2', 680, 480, true );
			add_image_size( 'bianco-post-3', 445, 300, true );
			add_image_size( 'bianco-post-4', 760, 400, true );
			add_image_size( 'bianco-page-banner-1', 1440, 500, true );
			add_image_size( 'bianco-page-banner-2', 1900, 500, true );
		}
		
		if( ! isset( $content_width ) ) {
			$content_width = 600;
		}
		
		if( is_singular() ) wp_enqueue_script( 'comment-reply' );
	}
	add_action( 'after_setup_theme', 'bianco_setup' );



	/*======
	*
	* Theme Scripts & Styles
	*
	======*/
	function bianco_scripts()
	{
		wp_enqueue_script( 'fixed-sidebar', get_template_directory_uri() . '/include/assets/js/fixed-sidebar.js', array(), false, true );
		wp_enqueue_script( 'popper', get_template_directory_uri() . '/include/assets/js/popper.min.js', array(), false, true );
		wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/include/assets/js/bootstrap.min.js', array(), false, true );
		wp_enqueue_script( 'jscrollpane', get_template_directory_uri() . '/include/assets/js/jscrollpane.min.js', array(), false, true );
		wp_enqueue_script( 'mousewheel', get_template_directory_uri() . '/include/assets/js/mousewheel.min.js', array(), false, true );
		wp_enqueue_script( 'plyr', get_template_directory_uri() . '/include/assets/js/plyr.min.js', array(), false, true );
		wp_enqueue_script( 'swiper', get_template_directory_uri() . '/include/assets/js/swiper.min.js', array(), false, true );
		wp_enqueue_script( 'tweenmax', get_template_directory_uri() . '/include/assets/js/tweenmax.min.js', array(), false, true );
		wp_enqueue_script( 'bianco', get_template_directory_uri() . '/include/assets/js/gtapp.js', array(), false, true );

		wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/include/assets/css/bootstrap.min.css' );
		wp_enqueue_style( 'fontawesome', get_template_directory_uri() . '/include/assets/css/fontawesome.min.css' );
		wp_enqueue_style( 'swiper', get_template_directory_uri() . '/include/assets/css/swiper.min.css' );
		wp_enqueue_style( 'bianco', get_stylesheet_uri() );
	}
	add_action( 'wp_enqueue_scripts', 'bianco_scripts' );



	/*======
	*
	* Admin Scripts & Styles
	*
	======*/
	function bianco_admin_scripts() {
		wp_enqueue_style( 'bianco-admin-metabox', get_template_directory_uri() . '/include/customize/assets/css/metabox.css', false, '1.0' );
		wp_enqueue_script( 'bianco-admin-metabox', get_template_directory_uri() . '/include/customize/assets/js/metabox.js', false, '1.0' );

		if ( is_customize_preview() ) {
			wp_enqueue_style( 'bianco-admin-customize', get_template_directory_uri() . '/include/customize/assets/css/customize.css', false, '1.0' );
			wp_enqueue_script( 'bianco-admin-customize', get_template_directory_uri() . '/include/customize/assets/js/customize.js', false, '1.0' );
		}
	}
	add_action( 'admin_enqueue_scripts', 'bianco_admin_scripts' );



	/*======
	*
	* Demo Importer
	*
	======*/
	function bianco_demo_content() {
		return array(
			array(
				'import_file_name' => esc_html__( 'Import Demo Content', 'bianco' ),
				'import_file_url' => get_template_directory_uri() . '/include/demos/demo-content.xml',
				'import_widget_file_url' => get_template_directory_uri() . '/include/demos/widget-content.wie',
			),
		);
	}
	add_filter( 'pt-ocdi/import_files', 'bianco_demo_content' );



	/*======
	*
	* Body Classes
	*
	======*/
	function bianco_class_names( $classes ) {
		$classes[] = 'bianco-theme';
		return $classes;
	}
	add_filter( 'body_class', 'bianco_class_names' );



	/*======
	*
	* Excerpt More
	*
	======*/
	function bianco_excerpt_more( $more ) {
		return '...';
	}
	add_filter( 'excerpt_more', 'bianco_excerpt_more' );



	/*======
	*
	* Excerpt Support for Pages
	*
	======*/
	function bianco_excerpts_for_pages() {
		add_post_type_support( 'page', 'excerpt' );
	}
	add_action( 'init', 'bianco_excerpts_for_pages' );



	/*======
	*
	* Pagination for Archive
	*
	======*/
	function bianco_pagination() {
		$args = array(
			'prev_text' => esc_html__( 'Prev', 'bianco' ),
			'next_text' => esc_html__( 'Next', 'bianco' ),
			'type' => 'list',
		);

		if( !empty( paginate_links( $args ) ) ) {
			echo '<div class="gt-pagination">';
				echo '<nav>';
					echo paginate_links( $args );
				echo '</nav>';
			echo '</div>';
		}
	}



	/*======
	*
	* Pagination for Elements
	*
	======*/
	function bianco_element_pagination( $paged = "", $query = "" ) {
		if( !empty( $paged ) or !empty( $query ) ) {
			$output = "";
			$args = array(
				'prev_text' => esc_html__( 'Prev', 'bianco' ),
				'next_text' => esc_html__( 'Next', 'bianco' ),
				'type' => 'list',
				'total' => $query->max_num_pages
			);

			if( !empty( paginate_links( $args ) ) ) {
				$output .= '<div class="gt-pagination">';
					$output .= '<nav>';
						$output .= paginate_links( $args );
					$output .= '</nav>';
				$output .= '</div>';
			}

			return $output;
		}
	}



	/*======
	*
	* Menus
	*
	======*/
	register_nav_menus( 
		array(
			'main-menu' => esc_html__( 'Main Menu', 'bianco' ),
			'footer-menu' => esc_html__( 'Footer Menu', 'bianco' ),
		)
	);



	/*======
	*
	* Menu Walker
	*
	======*/
	class bianco_walker extends Walker_Nav_Menu {
		public function start_lvl( &$output, $depth = 0, $args = array() ) {
			$indent = str_repeat( "\t", $depth );
			$output .= "\n$indent<ul role=\"menu\">\n";
		}

		function start_el( &$output, $item, $depth = 0, $args = array(), $id = 0 ) {

			$indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';

			$li_attributes = '';
			$class_names = $value = '';

			$classes = empty( $item->classes ) ? array() : (array) $item->classes;

			if ($args->has_children){
				$classes[] 		= 'dropdown';
				$li_attributes .= ' data-dropdown="dropdown"';
			}
			$classes[] = 'menu-item-' . $item->ID;
			$classes[] = ($item->current) ? 'active' : '';

			$class_names = join( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item, $args ) );
			$class_names = ' class="nav-item ' . esc_attr( $class_names ) . '"';

			$id = apply_filters( 'nav_menu_item_id', 'menu-item-'. $item->ID, $item, $args );
			$id = strlen( $id ) ? ' id="' . esc_attr( $id ) . '"' : '';

			$output .= $indent . '<li' . $id . $value . $class_names . $li_attributes . '>';

			$attributes  = ! empty( $item->attr_title ) ? ' title="'  . esc_attr( $item->attr_title ) .'"' : '';
			$attributes .= ! empty( $item->target ) ? ' target="' . esc_attr( $item->target ) .'"' : '';
			$attributes .= ! empty( $item->xfn ) ? ' rel="'    . esc_attr( $item->xfn ) .'"' : '';
			$attributes .= ! empty( $item->url ) ? ' href="'   . esc_attr( $item->url ) .'"' : '';
			$attributes .= ! empty( $item->url ) ? ' class="nav-link"' : '';
			$attributes .= ($args->has_children) ? ' ' : ''; 

			$item_output = $args->before;
			$item_output .= '<a'. $attributes .'>';
				$item_output .= $args->link_before;
				$item_output .= apply_filters( 'the_title', $item->title, $item->ID );
				$item_output .= $args->link_after;
			$item_output .= ($args->has_children) ? '' : '';
			$item_output .= '</a>';
			$item_output .= $args->after;

			$output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args );
		}

		public function display_element( $element, &$children_elements, $max_depth, $depth, $args, &$output ) {
	        if ( ! $element )
	            return;
	        $id_field = $this->db_fields['id'];
	        // Display this element.
	        if ( is_object( $args[0] ) )
	           $args[0]->has_children = ! empty( $children_elements[ $element->$id_field ] );
	        parent::display_element( $element, $children_elements, $max_depth, $depth, $args, $output );
	    }
	}



	/*======
	*
	* Search Form
	*
	======*/
	function bianco_search_form( $button = "true", $placeholder = "" ) {
		$output = '<form role="search" method="get" class="searchform" action="' . esc_url( home_url( '/' ) ) . '">';
			$output .= '<div class="search-form">';
				$output .= '<input type="text" value="' . esc_attr( get_search_query() ) . '" placeholder="' . esc_attr( $placeholder ) . '" name="s" class="searchform-text" />';
				if( $button == "true" ) {
					$output .= '<button><i class="fas fa-search" aria-hidden="true"></i></button>';					
				}
			$output .= '</div>';
		$output .= '</form>';

		return $output;
	}



	/*======
	*
	* Social Media Sites
	*
	======*/
	function bianco_social_media_sites() {
		$social_sites = bianco_social_media_array_filter();

		foreach ( $social_sites as $social_site => $profile ) {
			if ( strlen( get_theme_mod( $social_site ) ) > 0 ) {
				$active_social_sites[ $social_site ] = $social_site;
			}
		}

		if ( ! empty( $active_social_sites ) ) {
			$output = '<ul class="gt-social-links">';
				foreach ( $active_social_sites as $key => $active_site ) {
					$icon_class = 'fa-' . esc_attr( $active_site );
					$link_name = $active_site;
					$label = ucfirst( $active_site );

					if ( $active_site == 'twitter' ) {
						$label = esc_html__( 'Twitter', 'bianco' );
					} elseif ( $active_site == 'facebook' ) {
						$label = esc_html__( 'Facebook', 'bianco' );
						$icon_class = 'fa-facebook-f';
					} elseif ( $active_site == 'google-plus' ) {
						$label = esc_html__( 'Google Plus', 'bianco' );
						$icon_class = 'fa-google-plus-g';
					} elseif ( $active_site == 'pinterest' ) {
						$label = esc_html__( 'Pinterest', 'bianco' );
						$icon_class = 'fa-pinterest-p';
					} elseif ( $active_site == 'youtube' ) {
						$label = esc_html__( 'YouTube', 'bianco' );
					} elseif ( $active_site == 'vimeo' ) {
						$label = esc_html__( 'Vimeo', 'bianco' );
						$icon_class = 'fa-vimeo-v';
					} elseif ( $active_site == 'tumblr' ) {
						$label = esc_html__( 'Tumblr', 'bianco' );
					} elseif ( $active_site == 'instagram' ) {
						$label = esc_html__( 'Instagram', 'bianco' );
					} elseif ( $active_site == 'flickr' ) {
						$label = esc_html__( 'Flickr', 'bianco' );
					} elseif ( $active_site == 'dribbble' ) {
						$label = esc_html__( 'Dribbble', 'bianco' );
					} elseif ( $active_site == 'reddit' ) {
						$label = esc_html__( 'Reddit', 'bianco' );
						$icon_class = 'fa-reddit-alien';
					} elseif ( $active_site == 'soundcloud' ) {
						$label = esc_html__( 'SoundCloud', 'bianco' );
					} elseif ( $active_site == 'spotify' ) {
						$label = esc_html__( 'Spotify', 'bianco' );
					} elseif ( $active_site == 'yahoo' ) {
						$label = esc_html__( 'Yahoo', 'bianco' );
					} elseif ( $active_site == 'behance' ) {
						$label = esc_html__( 'Behance', 'bianco' );
					} elseif ( $active_site == 'delicious' ) {
						$label = esc_html__( 'Delicious', 'bianco' );
					} elseif ( $active_site == 'stumbleupon' ) {
						$label = esc_html__( 'Stumbleupon', 'bianco' );
					} elseif ( $active_site == 'deviantart' ) {
						$label = esc_html__( 'DeviantArt', 'bianco' );
					} elseif ( $active_site == 'digg' ) {
						$label = esc_html__( 'Digg', 'bianco' );
					} elseif ( $active_site == 'github' ) {
						$label = esc_html__( 'GitHub', 'bianco' );
					} elseif ( $active_site == 'medium' ) {
						$label = esc_html__( 'Medium', 'bianco' );
						$icon_class = 'fa-medium-m';
					} elseif ( $active_site == 'steam' ) {
						$label = esc_html__( 'Steam', 'bianco' );
						$icon_class = 'fa-steam-symbol';
					} elseif ( $active_site == 'vk' ) {
						$label = esc_html__( 'VK', 'bianco' );
					} elseif ( $active_site == '500px' ) {
						$label = esc_html__( '500px', 'bianco' );
					} elseif ( $active_site == 'foursquare' ) {
						$label = esc_html__( 'Foursquare', 'bianco' );
					} elseif ( $active_site == 'slack' ) {
						$label = esc_html__( 'Slack', 'bianco' );
						$icon_class = 'fa-slack-hash';
					} elseif ( $active_site == 'whatsapp' ) {
						$label = esc_html__( 'WhatsApp', 'bianco' );
					} elseif ( $active_site == 'twitch' ) {
						$label = esc_html__( 'Twitch', 'bianco' );
					} elseif ( $active_site == 'paypal' ) {
						$label = esc_html__( 'PayPal', 'bianco' );
					} elseif ( $active_site == 'rss' ) {
						$label = esc_html__( 'RSS', 'bianco' );
						$icon_class = 'fas fa-rss';
					} elseif ( $active_site == 'codepen' ) {
						$label = esc_html__( 'CodePen', 'bianco' );
					} elseif ( $active_site == 'linkedin' ) {
						$label = esc_html__( 'LinkedIn', 'bianco' );
						$icon_class = 'fa-linkedin-in';
					} elseif ( $active_site == 'custom-url' ) {
						$label = esc_html__( 'Custom Link', 'bianco' );
						$icon_class = 'fas fa-external-link-alt';
					}

					$output .='<li>';
						$target_name = $link_name . '-target';
						if( !empty( $target_name ) ) {
							if( !empty( get_theme_mod( $target_name ) ) or get_theme_mod( $target_name ) == "1" ) {
								$target = '_blank';
							} else {
								$target = '_self';
							}
						}
						$output .= '<a href="' . esc_url( get_theme_mod( $key ) ) . '" class="' . esc_attr( $link_name ) . '" title="' . esc_attr( $label ) . '" target="' . esc_attr( $target ) . '">';
							$output .= '<i class="fab ' . esc_attr( $icon_class ) . '"></i>';
						$output .= '</a>';
					$output .= '</li>';
				}
			$output .= '</ul>';

			return $output;
		}
	}



	/*======
	*
	* Social Share
	*
	======*/
	function bianco_social_share() {
		$output = "";
		$social_shares = bianco_social_share_array_filter();

		foreach ( $social_shares as $social_share => $value ) {
			if ( strlen( get_theme_mod( $social_share . '_share' ) ) == "1" ) {
				$active_share_sites[ $social_share . '_share' ] = $social_share . '_share';
			}
		}

		if ( !empty( $active_share_sites ) ) {
			$output = '<div class="gt-social-share">';
				$output .= '<ul>';
					foreach ( $active_share_sites as $key => $site ) {
						if ( $site == 'twitter' . '_share' ) {
							$label = esc_html__( 'Twitter', 'bianco' );
							$link = esc_url( 'https://twitter.com/intent/tweet?url=' . get_the_permalink() . '&text=' . urlencode( get_the_title() ) );
							$icon_class = 'fab fa-twitter';
							$icon_name = 'twitter';
						} elseif ( $site == 'facebook' . '_share' ) {
							$label = esc_html__( 'Facebook', 'bianco' );
							$link = esc_url( 'https://www.facebook.com/sharer/sharer.php?u=' . get_the_permalink() . '&t=' . urlencode( get_the_title() ) );
							$icon_class = 'fab fa-facebook-f';
							$icon_name = 'facebook';
						} elseif ( $site == 'google-plus' . '_share' ) {
							$label = esc_html__( 'Google+', 'bianco' );
							$link = esc_url( 'https://plus.google.com/share?url=' . get_the_permalink() );
							$icon_class = 'fab fa-google-plus-g';
							$icon_name = 'google-plus';
						} elseif ( $site == 'linkedin' . '_share' ) {
							$label = esc_html__( 'LinkedIn', 'bianco' );
							$link = esc_url( 'https://www.linkedin.com/shareArticle?mini=true&amp;url=' . get_the_permalink() . '&title=' . urlencode( get_the_title() ) );
							$icon_class = 'fab fa-linkedin-in';
							$icon_name = 'linkedin';
						} elseif ( $site == 'pinterest' . '_share' ) {
							$label = esc_html__( 'Pinterest', 'bianco' );
							$link = esc_url( 'https://pinterest.com/pin/create/button/?url=' . get_the_permalink() . '&description=' . urlencode( get_the_title() ) );
							$icon_class = 'fab fa-pinterest-p';
							$icon_name = 'pinterest';
						} elseif ( $site == 'reddit' . '_share' ) {
							$label = esc_html__( 'Reddit', 'bianco' );
							$link = esc_url( 'https://reddit.com/submit?url=' . get_the_permalink() . '&title=' . urlencode( get_the_title() ) );
							$icon_class = 'fab fa-reddit-alien';
							$icon_name = 'reddit';
						} elseif ( $site == 'delicious' . '_share' ) {
							$label = esc_html__( 'Delicious', 'bianco' );
							$link = esc_url( 'https://del.icio.us/post?url=' . get_the_permalink() );
							$icon_class = 'fab fa-delicious';
							$icon_name = 'delicious';
						} elseif ( $site == 'stumbleupon' . '_share' ) {
							$label = esc_html__( 'Stumbleupon', 'bianco' );
							$link = esc_url( 'https://www.stumbleupon.com/submit?url=' . get_the_permalink() . '&title=' . get_the_title() );
							$icon_class = 'fab fa-stumbleupon';
							$icon_name = 'stumbleupon';
						} elseif ( $site == 'tumblr' . '_share' ) {
							$label = esc_html__( 'Tumblr', 'bianco' );
							$link = esc_url( 'https://www.tumblr.com/share/link?url=' . get_the_permalink() );
							$icon_class = 'fab fa-tumblr';
							$icon_name = 'tumblr';
						} elseif ( $site == 'whatsapp' . '_share' ) {
							$label = esc_html__( 'WhatsApp', 'bianco' );
							$link = 'whatsapp://send?text=' . get_the_permalink();
							$icon_class = 'fab fa-whatsapp';
							$icon_name = 'whatsapp';
						} elseif ( $site == 'mail' . '_share' ) {
							$label = esc_html__( 'Email', 'bianco' );
							$link = 'mailto:' . get_the_permalink();
							$icon_class = 'far fa-envelope';
							$icon_name = 'envelope';
						}

						$link_name = $icon_name;
						$label = ucfirst( $label );

						if( is_single() or is_page() ) {
							$post = get_the_ID();						
						} else {
							$post = "";
						}

						if( $site == 'mail' . '_share' ) {
							$target = "_self";
						} else {
							$target = "_blank";
						}

						$output .='<li class="' . esc_attr( $link_name ) . '">';
							$output .= '<a href="' . $link . '" class="' . esc_attr( $link_name ) . '" title="' . esc_attr( $label ) . '" target="' . esc_attr( $target ) . '">';
								$output .= '<i class="' . esc_attr( $icon_class ) . '"></i>';
								$output .= '<span>' . esc_html__( 'Share on', 'bianco' ) . ' ' . esc_attr( $label ) . '</span>';
							$output .= '</a>';
						$output .= '</li>';
					}
				$output .= '</ul>';
			$output .= '</div>';
		}

		return $output;
	}



	/*======
	*
	* Social Media of Authors
	*
	======*/
	function bianco_user_social_links( $user_id = "" ) {
		$output = "";
		$user_social_sites = array(
			'facebook' => 'bianco_user_facebook_url',
			'twitter' => 'bianco_user_twitter_url',
			'google-plus' => 'bianco_user_googleplus_url',
			'pinterest' => 'bianco_user_pinterest_url',
			'linkedin' => 'bianco_user_linkedin_url',
			'youtube' => 'bianco_user_youtube_url',
			'vimeo' => 'bianco_user_vimeo_url',
			'tumblr' => 'bianco_user_tumblr_url',
			'instagram' => 'bianco_user_instagram_url',
			'flickr' => 'bianco_user_flickr_url',
			'dribbble' => 'bianco_user_dribbble_url',
			'reddit' => 'bianco_user_reddit_url',
			'soundcloud' => 'bianco_user_soundcloud_url',
			'spotify' => 'bianco_user_spotify_url',
			'yahoo' => 'bianco_user_yahoo_url',
			'behance' => 'bianco_user_behance_url',
			'codepen' => 'bianco_user_codepen_url',
			'delicious' => 'bianco_user_delicious_url',
			'stumbleupon' => 'bianco_user_stumbleupon_url',
			'deviantart' => 'bianco_user_deviantart_url',
			'digg' => 'bianco_user_digg_url',
			'github' => 'bianco_user_github_url',
			'medium' => 'bianco_user_medium_url',
			'steam' => 'bianco_user_steam_url',
			'vk' => 'bianco_user_vk_url',
			'500px' => 'bianco_user_500px_url',
			'foursquare' => 'bianco_user_foursquare_url',
			'slack' => 'bianco_user_slack_url',
			'whatsapp' => 'bianco_user_whatsapp_url',
			'skype' => 'bianco_user_skype_url',
			'twitch' => 'bianco_user_twitch_url',
			'paypal' => 'bianco_user_paypal_url',
			'custom-url' => 'bianco_user_custom_url',
		);

		foreach ( $user_social_sites as $user_social_site => $value ) {
			$active_sites[] = get_the_author_meta( $user_social_site, $user_id );
		}

		if( !empty( $active_sites ) ) {
			$output .= '<ul class="gt-social-list">';
				$author_url = get_the_author_meta( 'user_url' );
				if ( !empty( $author_url ) ) {
					$output .= '<li><a href="' . esc_url( $author_url ) . '" target="_blank"><i class="fas fa-link"></i></a></li>';
				}

				foreach ( $user_social_sites as $user_social_site => $value ) {
					$label = ucfirst( $user_social_site );
					$icon_class = 'fa-' . esc_attr( $user_social_site );

					if ( $user_social_site == 'twitter' ) {
						$label = esc_html__( 'Twitter', 'bianco' );
						$icon_name = 'twitter';
					} elseif ( $user_social_site == 'facebook' ) {
						$label = esc_html__( 'Facebook', 'bianco' );
						$icon_name = 'facebook';
						$icon_class = 'fa-facebook-f';
					} elseif ( $user_social_site == 'google-plus' ) {
						$label = esc_html__( 'Google Plus', 'bianco' );
						$icon_name = 'google-plus';
						$icon_class = 'fa-google-plus-g';
					} elseif ( $user_social_site == 'pinterest' ) {
						$label = esc_html__( 'Pinterest', 'bianco' );
						$icon_name = 'pinterest';
						$icon_class = 'fa-pinterest-p';
					} elseif ( $user_social_site == 'youtube' ) {
						$label = esc_html__( 'YouTube', 'bianco' );
						$icon_name = 'youtube';
					} elseif ( $user_social_site == 'vimeo' ) {
						$label = esc_html__( 'Vimeo', 'bianco' );
						$icon_name = 'vimeo';
						$icon_class = 'fa-vimeo-v';
					} elseif ( $user_social_site == 'tumblr' ) {
						$label = esc_html__( 'Tumblr', 'bianco' );
						$icon_name = 'tumblr';
					} elseif ( $user_social_site == 'instagram' ) {
						$label = esc_html__( 'Instagram', 'bianco' );
						$icon_name = 'instagram';
					} elseif ( $user_social_site == 'flickr' ) {
						$label = esc_html__( 'Flickr', 'bianco' );
						$icon_name = 'flickr';
					} elseif ( $user_social_site == 'dribbble' ) {
						$label = esc_html__( 'Dribbble', 'bianco' );
						$icon_name = 'dribbble';
					} elseif ( $user_social_site == 'reddit' ) {
						$label = esc_html__( 'Reddit', 'bianco' );
						$icon_name = 'reddit';
						$icon_class = 'fa-reddit-alien';
					} elseif ( $user_social_site == 'soundcloud' ) {
						$label = esc_html__( 'SoundCloud', 'bianco' );
						$icon_name = 'soundcloud';
					} elseif ( $user_social_site == 'spotify' ) {
						$label = esc_html__( 'Spotify', 'bianco' );
						$icon_name = 'spotify';
					} elseif ( $user_social_site == 'yahoo' ) {
						$label = esc_html__( 'Yahoo', 'bianco' );
						$icon_name = 'yahoo';
					} elseif ( $user_social_site == 'behance' ) {
						$label = esc_html__( 'Behance', 'bianco' );
						$icon_name = 'behance';
					} elseif ( $user_social_site == 'delicious' ) {
						$label = esc_html__( 'Delicious', 'bianco' );
						$icon_name = 'delicious';
					} elseif ( $user_social_site == 'stumbleupon' ) {
						$label = esc_html__( 'Stumbleupon', 'bianco' );
						$icon_name = 'stumbleupon';
					} elseif ( $user_social_site == 'deviantart' ) {
						$label = esc_html__( 'DeviantArt', 'bianco' );
						$icon_name = 'deviantart';
					} elseif ( $user_social_site == 'digg' ) {
						$label = esc_html__( 'Digg', 'bianco' );
						$icon_name = 'digg';
					} elseif ( $user_social_site == 'github' ) {
						$label = esc_html__( 'GitHub', 'bianco' );
						$icon_name = 'github';
					} elseif ( $user_social_site == 'medium' ) {
						$label = esc_html__( 'Medium', 'bianco' );
						$icon_name = 'medium';
						$icon_class = 'fa-medium-m';
					} elseif ( $user_social_site == 'steam' ) {
						$label = esc_html__( 'Steam', 'bianco' );
						$icon_name = 'steam';
						$icon_class = 'fa-steam-symbol';
					} elseif ( $user_social_site == 'vk' ) {
						$label = esc_html__( 'VK', 'bianco' );
						$icon_name = 'vk';
					} elseif ( $user_social_site == '500px' ) {
						$label = esc_html__( '500px', 'bianco' );
						$icon_name = '500px';
					} elseif ( $user_social_site == 'foursquare' ) {
						$label = esc_html__( 'Foursquare', 'bianco' );
						$icon_name = 'foursquare';
					} elseif ( $user_social_site == 'slack' ) {
						$label = esc_html__( 'Slack', 'bianco' );
						$icon_name = 'slack';
						$icon_class = 'fa-slack-hash';
					} elseif ( $user_social_site == 'whatsapp' ) {
						$label = esc_html__( 'WhatsApp', 'bianco' );
						$icon_name = 'whatsapp';
					} elseif ( $user_social_site == 'twitch' ) {
						$label = esc_html__( 'Twitch', 'bianco' );
						$icon_name = 'twitch';
					} elseif ( $user_social_site == 'paypal' ) {
						$label = esc_html__( 'PayPal', 'bianco' );
						$icon_name = 'paypal';
					} elseif ( $user_social_site == 'codepen' ) {
						$label = esc_html__( 'CodePen', 'bianco' );
						$icon_name = 'codepen';
					} elseif ( $user_social_site == 'linkedin' ) {
						$label = esc_html__( 'LinkedIn', 'bianco' );
						$icon_name = 'linkedin';
						$icon_class = 'fa-linkedin-in';
					} elseif ( $user_social_site == 'custom-url' ) {
						$label = esc_html__( 'Link', 'bianco' );
						$icon_name = 'link';
						$icon_class = 'fas fa-external-link-alt';
					}

					$user_social_site = get_the_author_meta( $user_social_site, $user_id );
					if( !empty( $user_social_site ) ) {
						$output .= '<li><a href="' . esc_url( $user_social_site ) . '" title="' . esc_attr( $label ) . '" target="_blank"><i class="fab ' . esc_attr( $icon_class ) . '"></i></a></li>';
					}
				}
			$output .= '</ul>';
		}

		return $output;
	}



	/*======
	*
	* Loader
	*
	======*/
	function bianco_loader() {
		$output = "";

		$loader = get_theme_mod( 'bianco_loader', '1' );
		$loader_logo = get_theme_mod( 'bianco_loader_logo' );

		if( $loader == "1" ) {
			$output .= '<div class="gt-loader">';
				$output .= '<div class="gt-sticks">';
					$output .= '<div class="gt-stick"></div>';
					$output .= '<div class="gt-stick"></div>';
					$output .= '<div class="gt-stick"></div>';
					$output .= '<div class="gt-stick"></div>';
					$output .= '<div class="gt-stick"></div>';
				$output .= '</div>';

				if( !empty( $loader_logo ) ) {
					$output .= '<div class="gt-logo">';
						$output .= '<span>';
							$output .= '<img alt="' . esc_attr( get_bloginfo( 'name' ) ) . '" src="' . esc_url( wp_get_attachment_url( $loader_logo ) ) . '" />';
						$output .= '</span>';
					$output .= '</div>';
				}
			$output .= '</div>';
		}

		return $output;
	}



	/*======
	*
	* Comment List Template
	*
	======*/
	function bianco_comment( $comment, $args, $depth ) {
		$GLOBALS['comment'] = $comment;
		extract($args, EXTR_SKIP);

		if ( 'div' == $args['style'] ) {
			$tag = 'div';
			$add_below = 'comment';
		} else {
			$tag = 'li';
			$add_below = 'div-comment';
		}
		?>
			<<?php echo esc_attr( $tag ) ?> <?php comment_class( empty( $args['has_children'] ) ? '' : 'parent' ) ?> id="comment-<?php comment_ID() ?>">
			
			<?php if ( 'div' != $args['style'] ) { ?>
				<div id="div-comment-<?php comment_ID() ?>" class="gt-comment-wrapper">
			<?php } ?>
				<div class="gt-user-avatar">
					<?php $user = get_user_by( 'email', $comment->comment_author_email ); ?>
					<?php if ( $args['avatar_size'] != 0 ) { echo get_avatar( $comment, $args['avatar_size'] ); } ?>
				</div>

				<div class="gt-comment-content">
					<div class="gt-comment-user">
						<?php
							$author_control = get_comment_author();
							if( !empty( $author_control ) ) {
								echo get_comment_author(); 
							}
						?>
					</div>

					<?php if ( $comment->comment_approved == '0' ) { ?>
						<p class="moderation-message"><?php echo esc_html__( 'Your comment is awaiting moderation.', 'bianco' ); ?></p>
					<?php } ?>

					<?php comment_text(); ?>

					<div class="gt-comment-details">
						<div class="gt-item comment-meta commentmetadata">
							<i class="far fa-clock" aria-hidden="true"></i>
							<a href="<?php echo htmlspecialchars( get_comment_link( $comment->comment_ID ) ); ?>">
								<?php printf( esc_html__( '%1$s', 'bianco' ), get_comment_date(),  get_comment_time() ); ?>
							</a>
						</div>
						
						<?php comment_reply_link( array_merge( $args, array( 'add_below' => $add_below, 'depth' => $depth, 'max_depth' => $args['max_depth'], 'before' => '<div class="gt-item reply"><i class="fas fa-reply" aria-hidden="true"></i>', 'after' => '</div>' ) ) ); ?>
						
						<?php edit_comment_link( esc_html__( 'Edit', 'bianco' ), '<div class="gt-item edit"><i class="fas fa-pencil-alt" aria-hidden="true"></i>', '</div>' ); ?>
					</div>
				</div>

			<?php if ( 'div' != $args['style'] ) { ?>
				</div>
			<?php }
	}



	/*======
	*
	* WooCommerce Support
	*
	======*/
	if( class_exists( 'Woocommerce' ) ) {
		function bianco_woocommerce_support() {
			add_theme_support( 'woocommerce' );
		}
		add_action( 'after_setup_theme', 'bianco_woocommerce_support' );
	}



	/*======
	*
	* Sidebars
	*
	======*/
	if( !function_exists( 'bianco_sidebars_init' ) ) {
		function bianco_sidebars_init() {
			register_sidebar(
				array(
					'id' => 'bianco-sidebar',
					'name' => esc_html__( 'General Sidebar', 'bianco' ),
					'before_widget' => '<div id="%1$s" class="gt-widget %2$s">',
					'after_widget' => '</div>',
					'before_title' => '<div class="gt-widget--heading"><div class="gt-widget--icon"><i class="fas fa-genderless"></i></div><div class="gt-widget--title">',
					'after_title' => '</div></div>',
				)
			);

			register_sidebar(
				array(
					'id' => 'bianco-shop-sidebar',
					'name' => esc_html__( 'Shop Sidebar', 'bianco' ),
					'before_widget' => '<div id="%1$s" class="gt-widget %2$s">',
					'after_widget' => '</div>',
					'before_title' => '<div class="gt-widget--heading"><div class="gt-widget--icon"><i class="fas fa-genderless"></i></div><div class="gt-widget--title">',
					'after_title' => '</div></div>',
				)
			);
		}
	}
	add_action( 'widgets_init', 'bianco_sidebars_init' );



	/*======
	*
	* Sidebar & Wrapper Layouts
	*
	======*/
	function bianco_content_before() {
		if( is_category() ) {
			$sidebar_position = get_theme_mod( 'bianco_categories_sidebar_position', 'right-sidebar' );
		} elseif( is_search() ) {
			$sidebar_position = get_theme_mod( 'bianco_searches_sidebar_position', 'right-sidebar' );
		} elseif( is_woocommerce() ) {
			$sidebar_position = get_theme_mod( 'bianco_woo_sidebar_position', 'no-sidebar' );
		} elseif( is_tag() ) {
			$sidebar_position = get_theme_mod( 'bianco_tags_sidebar_position', 'right-sidebar' );
		} elseif( is_author() ) {
			$sidebar_position = get_theme_mod( 'bianco_authors_sidebar_position', 'right-sidebar' );
		} elseif( is_archive() ) {
			$sidebar_position = get_theme_mod( 'bianco_archives_sidebar_position', 'right-sidebar' );
		} elseif( is_attachment() ) {
			$sidebar_position = get_theme_mod( 'bianco_attachments_sidebar_position', 'no-sidebar' );
		} elseif( is_singular( 'post' ) ) {
			$sidebar_position = get_theme_mod( 'bianco_posts_sidebar_position', 'no-sidebar' );
		} elseif( is_page() ) {
			$sidebar_position = get_theme_mod( 'bianco_pages_sidebar_position', 'no-sidebar' );
		} else {
			$sidebar_position = get_theme_mod( 'bianco_general_sidebar_position', 'right-sidebar' );
		}

		if( is_singular( 'post' ) or is_page() ) {
			$custom_sidebar_position = get_post_meta( get_the_ID(), 'sidebar-position', true );
			if( !empty( $custom_sidebar_position ) ) {
				$sidebar_position = $custom_sidebar_position;
			}

			$narrow_layout = get_post_meta( get_the_ID(), 'page-narrow-layout', true );
			if( !empty( $narrow_layout ) ) {
				$narrow = $narrow_layout;
			} else {
				$narrow = "";
			}
		} else {
			$narrow = "";
		}

		if( $sidebar_position == 'no-sidebar' ) {
			if( is_singular( 'post' ) or $narrow == "1" ) {
				echo '<div class="col-lg-8 gt-single-no-sidebar">';
			} else {
				echo '<div class="col-lg-12">';
			}
		}
		
		elseif( $sidebar_position == 'left-sidebar' ) {
			echo '<div class="col-lg-8">';
		}
		
		elseif( $sidebar_position == 'right-sidebar' ) {
			echo '<div class="col-lg-8">';
		}
		
		else {
			echo '<div class="col-lg-8">';
		}
	}

	function bianco_content_after() {
		echo '</div>';
	}

	function bianco_sidebar_before() {
		if( is_category() ) {
			$sidebar_position = get_theme_mod( 'bianco_categories_sidebar_position', 'right-sidebar' );
		} elseif( is_search() ) {
			$sidebar_position = get_theme_mod( 'bianco_searches_sidebar_position', 'right-sidebar' );
		} elseif( is_woocommerce() ) {
			$sidebar_position = get_theme_mod( 'bianco_woo_sidebar_position', 'no-sidebar' );
		} elseif( is_tag() ) {
			$sidebar_position = get_theme_mod( 'bianco_tags_sidebar_position', 'right-sidebar' );
		} elseif( is_author() ) {
			$sidebar_position = get_theme_mod( 'bianco_authors_sidebar_position', 'right-sidebar' );
		} elseif( is_archive() ) {
			$sidebar_position = get_theme_mod( 'bianco_archives_sidebar_position', 'right-sidebar' );
		} elseif( is_attachment() ) {
			$sidebar_position = get_theme_mod( 'bianco_attachments_sidebar_position', 'no-sidebar' );
		} elseif( is_singular( 'post' ) ) {
			$sidebar_position = get_theme_mod( 'bianco_posts_sidebar_position', 'no-sidebar' );
		} elseif( is_page() ) {
			$sidebar_position = get_theme_mod( 'bianco_pages_sidebar_position', 'no-sidebar' );
		} else {
			$sidebar_position = get_theme_mod( 'bianco_general_sidebar_position', 'right-sidebar' );
		}

		if( is_singular( 'post' ) or is_page() ) {
			$custom_sidebar_position = get_post_meta( get_the_ID(), 'sidebar-position', true );
			if( !empty( $custom_sidebar_position ) ) {
				$sidebar_position = $custom_sidebar_position;
			}

			$narrow_layout = get_post_meta( get_the_ID(), 'page-narrow-layout', true );
			if( !empty( $narrow_layout ) ) {
				$narrow = $narrow_layout;
			} else {
				$narrow = "";
			}
		} else {
			$narrow = "";
		}
		
		if( $sidebar_position == 'no-sidebar' ) {
			if( is_singular( 'post' ) or $narrow == "1" ) {
				echo '<div class="col-lg-12 d-none">';
			} else {
				echo '<div class="col-lg-12 d-none">';
			}
		}
		
		elseif( $sidebar_position == 'left-sidebar' ) {
			echo '<div class="col-lg-4 gt-fixed-sidebar gt-left-sidebar">';
		}
		
		elseif( $sidebar_position == 'right-sidebar' ) {
			echo '<div class="col-lg-4 gt-fixed-sidebar">';
		}
		
		else {
			echo '<div class="col-lg-4 gt-fixed-sidebar">';
		}
	}

	function bianco_sidebar_after() {
		echo '</div>';
	}



	/*======
	*
	* Theme Wrapper
	*
	======*/
	function bianco_wrapper_before() {
		$output = '<main class="gt-main">';
		return $output;
	}

	function bianco_wrapper_after() {
		$output = '</main>';
		return $output;
	}



	/*======
	*
	* Row Wrapper
	*
	======*/
	function bianco_row_before( $extra_class = "", $echo = "true" ) {
		if( !empty( $extra_class ) ) {
			$extra_class = ' ' . $extra_class;
		}

		if( $echo == "true" ) {
			echo '<div class="row' . $extra_class . '">';
		} else {
			$output = '<div class="row' . $extra_class . '">';
			return $output;
		}
	}

	function bianco_row_after( $echo = "true" ) {
		if( $echo == "true" ) {
			echo '</div>';
		} else {
			$output = '</div>';
			return $output;
		}
	}



	/*======
	*
	* Container Wrapper
	*
	======*/
	function bianco_container_before( $extra_class = "", $echo = "true" ) {
		if( !empty( $extra_class ) ) {
			$extra_class = ' ' . $extra_class;
		}

		if( $echo == "true" ) {
			echo '<div class="container' . $extra_class . '">';
		} else {
			$output = '<div class="container' . $extra_class . '">';
			return $output;
		}
	}

	function bianco_container_after( $echo = "true" ) {
		if( $echo == "true" ) {
			echo '</div>';
		} else {
			$output = '</div>';
			return $output;
		}
	}



	/*======
	*
	* Site Logo
	*
	======*/
	function bianco_site_logo() {
		$output = "";

		$logo = get_theme_mod( 'bianco_header_logo' );

		$logo_height = get_theme_mod( 'bianco_header_logo_height' );
		if( !empty( $logo_height ) ) {
			$logo_height = 'height="' . esc_attr( $logo_height ) . '"';
		}

		$logo_width = get_theme_mod( 'bianco_header_logo_width' );
		if( !empty( $logo_width ) ) {
			$logo_width = 'width="' . esc_attr( $logo_width ) . '"';
		}

		if( !$logo == ""  ) {
			$output .= '<a href="' . esc_url( home_url( '/' ) ) . '" title="' . esc_attr( get_bloginfo( 'name' ) ) . '">';
				$output .= '<img alt="' . esc_attr( get_bloginfo( 'name' ) ) . '" src="' . esc_url( wp_get_attachment_url( $logo ) ) . '" ' . $logo_height . $logo_width . ' />';
			$output .= '</a>';
		} else {
			$output .= '<a href="' . esc_url( home_url( '/' ) ) . '" title="' . esc_attr( get_bloginfo( 'name' ) ) . '">';
				$output .= '<span>' . esc_attr( get_bloginfo( 'name' ) ) . '</span>';
			$output .= '</a>';
		}

		return $output;
	}



	/*======
	*
	* Page Banner
	*
	======*/
	function bianco_page_banner( $title = "", $top_text = "", $custom_background = "", $style = "", $post_id = "" ) {
		$output = "";

		if( !empty( $custom_background ) ) {
			foreach ( $custom_background as $bg ) {
				$bg_id = $bg["ID"];
			}
		} else {
			$bg_id = "";
		}

		$image_url = wp_get_attachment_image_src( esc_attr( $bg_id ), 'bianco-page-banner-2' );
		$audio_code = rwmb_meta( 'audio-header-code' );

		if( $style == "style-2" ) {
			$output .= '<section class="gt-page-heading gt-style-2">';
				$output .= '<div class="gt-container">';
					$output .= '<div class="gt-image">';
						if( !empty( $image_url ) ) {
							$image_url = $image_url[0];
							$output .= '<div class="gt-image-inner" style="background-image:url(' . esc_url( $image_url ) . ');"></div>';
						}

						$output .= '<div class="gt-content">';
							if( is_single() ) {
								if ( !empty( get_the_category_list( ", ", '', $post_id ) ) ) {
									$output .= '<span>';
										$output .= get_the_category_list( ", ", '', $post_id );
									$output .= '</span>';
								}
							} elseif( is_page() ) {
								$output .= '<span>' . esc_attr( $top_text ) . '</span>';
							}

							if( !empty( $title ) ) {
								$output .= '<h1>' . esc_attr( $title ) . '</h1>';
							} else {
								if( is_category() ) {
									$title = single_cat_title( '', false );
								} elseif( is_tag() ) {
									$title = single_tag_title( '', false );
								} elseif( is_search() ) {
									$title = get_search_query();
								} elseif( is_author() ) {
									$title = get_the_author();
								} elseif( is_home() ) {
									$title = esc_html__( 'Home', 'bianco' );
								} elseif( is_404() ) {
									$title = esc_html__( '404 Page', 'bianco' );
								} elseif( is_attachment() or is_page() or is_single() ) {
									$title = get_the_title();
								} elseif(  is_post_type_archive() ) {
									$title = post_type_archive_title( '', false );
								} elseif(  is_tax() ) {
									$title = single_term_title( '', false );
								} else {
									if ( is_day() ) {
										$title = sprintf( esc_html__( 'Daily Archives: %s', 'bianco' ), get_the_date() );
									} elseif ( is_month() ) {
										$title = sprintf( esc_html__( 'Monthly Archives: %s', 'bianco' ), get_the_date( _x( 'F Y', 'Monthly archives date format', 'bianco' ) ) );
									} elseif ( is_year() ) {
										$title = sprintf( esc_html__( 'Yearly Archives: %s', 'bianco' ), get_the_date( _x( 'Y', 'Yearly archives date format', 'bianco' ) ) );
									} else {
										$title = esc_html__( 'Archives', 'bianco' );
									}
								}
								$output .= '<h1>' . esc_attr( $title ) . '</h1>';
							}

							if( is_single() ) {
								$output .= '<ul>';
									if ( comments_open() ) {
										$output .= '<li>';
											$num_comments = get_comments_number();
											if ( $num_comments == 0 ) {
												$comments = esc_html__( '0 Comment', 'bianco' );
											} elseif ( $num_comments > 1 ) {
												$comments = $num_comments . ' ' . esc_html__( 'Comments', 'bianco' );
											} else {
												$comments = esc_html__( '1 Comment', 'bianco' );
											}
											$output .= $comments;
										$output .= '</li>';
									}

									$output .= '<li>';
										$output .= get_the_time( get_option( 'date_format' ) );
									$output .= '</li>';
								$output .= '</ul>';
							}
						$output .= '</div>';
					$output .= '</div>';
				$output .= '</div>';
			$output .= '</section>';
		} elseif( $style == "style-3" ) {
			$output .= '<section class="gt-page-heading gt-style-3">';
				$output .= '<div class="gt-container">';
					if( !empty( $image_url ) ) {
						$output .= '<div class="gt-image">';
							$image_url = $image_url[0];
							$output .= '<div class="gt-image-inner" style="background-image:url(' . esc_url( $image_url ) . ');"></div>';
							$output .= '<button type="button" class="gt-btn gt-modal-video" data-toggle="modal" data-target=".gt-video-modal"><i class="fas fa-play"></i></button>';
						$output .= '</div>';
					}


					if ( function_exists( 'rwmb_meta' ) ) {
						$video_url = get_post_meta( get_the_ID(), 'video-header-url', true );
						$args = ['width' => 640];
						$embed = wp_oembed_get( $video_url, $args );
						if ( ! $embed ) {
							$embed = $GLOBALS['wp_embed']->shortcode( $args, $video_url );
						}
						if ( $embed ) {
							$video = rwmb_meta( 'video-header-url' );
							if( !empty( $video ) ) {
                                $output .= '<div class="modal fade gt-video-modal" tabindex="-1" role="dialog" aria-hidden="true">';
                                    $output .= '<div class="modal-dialog modal-lg modal-dialog-centered">';
                                        $output .= '<div class="modal-content">';
											$output .= rwmb_meta( 'video-header-url' );
                                       $output .= ' </div>';
                                    $output .= '</div>';
                               $output .= ' </div>';
							}
						}
					}

					$output .= '<div class="gt-content">';
						if( is_single() ) {
							if ( !empty( get_the_category_list( ", ", '', $post_id ) ) ) {
								$output .= '<span>';
									$output .= get_the_category_list( ", ", '', $post_id );
								$output .= '</span>';
							}
						} elseif( is_page() ) {
							$output .= '<span>' . esc_attr( $top_text ) . '</span>';
						}

						if( !empty( $title ) ) {
							$output .= '<h1>' . esc_attr( $title ) . '</h1>';
						} else {
							if( is_category() ) {
								$title = single_cat_title( '', false );
							} elseif( is_tag() ) {
								$title = single_tag_title( '', false );
							} elseif( is_search() ) {
								$title = get_search_query();
							} elseif( is_author() ) {
								$title = get_the_author();
							} elseif( is_home() ) {
								$title = esc_html__( 'Home', 'bianco' );
							} elseif( is_404() ) {
								$title = esc_html__( '404 Page', 'bianco' );
							} elseif( is_attachment() or is_page() or is_single() ) {
								$title = get_the_title();
							} elseif(  is_post_type_archive() ) {
								$title = post_type_archive_title( '', false );
							} elseif(  is_tax() ) {
								$title = single_term_title( '', false );
							} else {
								if ( is_day() ) {
									$title = sprintf( esc_html__( 'Daily Archives: %s', 'bianco' ), get_the_date() );
								} elseif ( is_month() ) {
									$title = sprintf( esc_html__( 'Monthly Archives: %s', 'bianco' ), get_the_date( _x( 'F Y', 'Monthly archives date format', 'bianco' ) ) );
								} elseif ( is_year() ) {
									$title = sprintf( esc_html__( 'Yearly Archives: %s', 'bianco' ), get_the_date( _x( 'Y', 'Yearly archives date format', 'bianco' ) ) );
								} else {
									$title = esc_html__( 'Archives', 'bianco' );
								}
							}
							$output .= '<h1>' . esc_attr( $title ) . '</h1>';
						}

						if( is_single() ) {
							$output .= '<ul>';
								if ( comments_open() ) {
									$output .= '<li>';
										$num_comments = get_comments_number();
										if ( $num_comments == 0 ) {
											$comments = esc_html__( '0 Comment', 'bianco' );
										} elseif ( $num_comments > 1 ) {
											$comments = $num_comments . ' ' . esc_html__( 'Comments', 'bianco' );
										} else {
											$comments = esc_html__( '1 Comment', 'bianco' );
										}
										$output .= $comments;
									$output .= '</li>';
								}

								$output .= '<li>';
									$output .= get_the_time( get_option( 'date_format' ) );
								$output .= '</li>';
							$output .= '</ul>';
						}
					$output .= '</div>';
				$output .= '</div>';
			$output .= '</section>';
		} elseif( $style == "style-4" ) {
			$output .= '<section class="gt-page-heading gt-style-3">';
				$output .= '<div class="gt-container">';
					if( !empty( $audio_code ) ) {
						$output .= '<div class="gt-code">';
							$output .= rwmb_meta( 'audio-header-code' );
						$output .= '</div>';
					}

					$output .= '<div class="gt-content">';
						if( is_single() ) {
							if ( !empty( get_the_category_list( ", ", '', $post_id ) ) ) {
								$output .= '<span>';
									$output .= get_the_category_list( ", ", '', $post_id );
								$output .= '</span>';
							}
						} elseif( is_page() ) {
							$output .= '<span>' . esc_attr( $top_text ) . '</span>';
						}

						if( !empty( $title ) ) {
							$output .= '<h1>' . esc_attr( $title ) . '</h1>';
						} else {
							if( is_category() ) {
								$title = single_cat_title( '', false );
							} elseif( is_tag() ) {
								$title = single_tag_title( '', false );
							} elseif( is_search() ) {
								$title = get_search_query();
							} elseif( is_author() ) {
								$title = get_the_author();
							} elseif( is_home() ) {
								$title = esc_html__( 'Home', 'bianco' );
							} elseif( is_404() ) {
								$title = esc_html__( '404 Page', 'bianco' );
							} elseif( is_attachment() or is_page() or is_single() ) {
								$title = get_the_title();
							} elseif(  is_post_type_archive() ) {
								$title = post_type_archive_title( '', false );
							} elseif(  is_tax() ) {
								$title = single_term_title( '', false );
							} else {
								if ( is_day() ) {
									$title = sprintf( esc_html__( 'Daily Archives: %s', 'bianco' ), get_the_date() );
								} elseif ( is_month() ) {
									$title = sprintf( esc_html__( 'Monthly Archives: %s', 'bianco' ), get_the_date( _x( 'F Y', 'Monthly archives date format', 'bianco' ) ) );
								} elseif ( is_year() ) {
									$title = sprintf( esc_html__( 'Yearly Archives: %s', 'bianco' ), get_the_date( _x( 'Y', 'Yearly archives date format', 'bianco' ) ) );
								} else {
									$title = esc_html__( 'Archives', 'bianco' );
								}
							}
							$output .= '<h1>' . esc_attr( $title ) . '</h1>';
						}

						if( is_single() ) {
							$output .= '<ul>';
								if ( comments_open() ) {
									$output .= '<li>';
										$num_comments = get_comments_number();
										if ( $num_comments == 0 ) {
											$comments = esc_html__( '0 Comment', 'bianco' );
										} elseif ( $num_comments > 1 ) {
											$comments = $num_comments . ' ' . esc_html__( 'Comments', 'bianco' );
										} else {
											$comments = esc_html__( '1 Comment', 'bianco' );
										}
										$output .= $comments;
									$output .= '</li>';
								}

								$output .= '<li>';
									$output .= get_the_time( get_option( 'date_format' ) );
								$output .= '</li>';
							$output .= '</ul>';
						}
					$output .= '</div>';
				$output .= '</div>';
			$output .= '</section>';
		} else {
			if( !empty( $image_url ) ) {
				$image_url = $image_url[0];
				$output .= '<section class="gt-page-heading gt-style-1" style="background-image:url(' . esc_url( $image_url ) . ');">';
			} else {
				$output .= '<section class="gt-page-heading gt-style-1">';
			}
				$output .= '<div class="container">';
					$output .= '<div class="gt-content">';
						if( is_single() ) {
							if ( !empty( get_the_category_list( ", ", '', $post_id ) ) ) {
								$output .= '<span>';
									$output .= get_the_category_list( ", ", '', $post_id );
								$output .= '</span>';
							}
						} elseif( is_page() ) {
							$output .= '<span>' . esc_attr( $top_text ) . '</span>';
						}

						if( !empty( $title ) ) {
							$output .= '<h1>' . esc_attr( $title ) . '</h1>';
						} else {
							if( is_category() ) {
								$title = single_cat_title( '', false );
							} elseif( is_tag() ) {
								$title = single_tag_title( '', false );
							} elseif( is_search() ) {
								$title = get_search_query();
							} elseif( is_author() ) {
								$title = get_the_author();
							} elseif( is_home() ) {
								$title = esc_html__( 'Home', 'bianco' );
							} elseif( is_404() ) {
								$title = esc_html__( '404 Page', 'bianco' );
							} elseif( is_attachment() or is_page() or is_single() ) {
								$title = get_the_title();
							} elseif(  is_post_type_archive() ) {
								$title = post_type_archive_title( '', false );
							} elseif(  is_tax() ) {
								$title = single_term_title( '', false );
							} else {
								if ( is_day() ) {
									$title = sprintf( esc_html__( 'Daily Archives: %s', 'bianco' ), get_the_date() );
								} elseif ( is_month() ) {
									$title = sprintf( esc_html__( 'Monthly Archives: %s', 'bianco' ), get_the_date( _x( 'F Y', 'Monthly archives date format', 'bianco' ) ) );
								} elseif ( is_year() ) {
									$title = sprintf( esc_html__( 'Yearly Archives: %s', 'bianco' ), get_the_date( _x( 'Y', 'Yearly archives date format', 'bianco' ) ) );
								} else {
									$title = esc_html__( 'Archives', 'bianco' );
								}
							}
							$output .= '<h1>' . esc_attr( $title ) . '</h1>';
						}

						if( is_single() ) {
							$output .= '<ul>';
								if ( comments_open() ) {
									$output .= '<li>';
										$num_comments = get_comments_number();
										if ( $num_comments == 0 ) {
											$comments = esc_html__( '0 Comment', 'bianco' );
										} elseif ( $num_comments > 1 ) {
											$comments = $num_comments . ' ' . esc_html__( 'Comments', 'bianco' );
										} else {
											$comments = esc_html__( '1 Comment', 'bianco' );
										}
										$output .= $comments;
									$output .= '</li>';
								}

								$output .= '<li>';
									$output .= get_the_time( get_option( 'date_format' ) );
								$output .= '</li>';
							$output .= '</ul>';
						}
					$output .= '</div>';
				$output .= '</div>';
			$output .= '</section>';
		}

		return $output;
	}



	/*======
	*
	* Header Elements
	*
	======*/
	function bianco_header_elements( $social = "true", $cart = "true", $menu = "true" ) {
		$output = "";
		$header_social_media = get_theme_mod( 'bianco_header_social_media', '1' );
		$header_search = get_theme_mod( 'bianco_header_search', '1' );
		$header_cart = get_theme_mod( 'bianco_header_cart', '1' );
		$header_menu = get_theme_mod( 'bianco_header_menu', '1' );

		if( $social == "true" ) {
			if( $header_social_media == "1" ) {
				$output .= '<div class="gt-icon">';
					$output .= '<div class="gt-icon--dropdown">';
						$output .= bianco_social_media_sites();
					$output .= '</div>';
					$output .= '<svg viewBox="0 0 18 20" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g> <path d="M14.3333333,20 C12.3054894,20 10.6666667,18.340692 10.6666667,16.3 C10.6666667,14.259308 12.3054894,12.6 14.3333333,12.6 C16.3611772,12.6 18,14.259308 18,16.3 C18,18.340692 16.3611772,20 14.3333333,20 Z M14.3333333,18 C15.2510081,18 16,17.2416457 16,16.3 C16,15.3583543 15.2510081,14.6 14.3333333,14.6 C13.4156586,14.6 12.6666667,15.3583543 12.6666667,16.3 C12.6666667,17.2416457 13.4156586,18 14.3333333,18 Z M3.66666667,13.7 C1.63882276,13.7 0,12.040692 0,10 C0,7.95930805 1.63882276,6.3 3.66666667,6.3 C5.69451057,6.3 7.33333333,7.95930805 7.33333333,10 C7.33333333,12.040692 5.69451057,13.7 3.66666667,13.7 Z M3.66666667,11.7 C4.58434143,11.7 5.33333333,10.9416457 5.33333333,10 C5.33333333,9.0583543 4.58434143,8.3 3.66666667,8.3 C2.74899191,8.3 2,9.0583543 2,10 C2,10.9416457 2.74899191,11.7 3.66666667,11.7 Z M14.3333333,7.4 C12.3054894,7.4 10.6666667,5.74069195 10.6666667,3.7 C10.6666667,1.65930805 12.3054894,0 14.3333333,0 C16.3611772,0 18,1.65930805 18,3.7 C18,5.74069195 16.3611772,7.4 14.3333333,7.4 Z M14.3333333,5.4 C15.2510081,5.4 16,4.6416457 16,3.7 C16,2.7583543 15.2510081,2 14.3333333,2 C13.4156586,2 12.6666667,2.7583543 12.6666667,3.7 C12.6666667,4.6416457 13.4156586,5.4 14.3333333,5.4 Z M5.46073535,12.2202665 C4.985071,11.939621 4.82697694,11.3265108 5.10762239,10.8508465 C5.38826784,10.3751821 6.00137808,10.2170881 6.47704243,10.4977335 L12.5481535,14.0797335 C13.0238179,14.360379 13.1819119,14.9734892 12.9012665,15.4491535 C12.620621,15.9248179 12.0075108,16.0829119 11.5318465,15.8022665 L5.46073535,12.2202665 Z M11.5224052,4.19805965 C11.9978894,3.91710913 12.6111009,4.07480985 12.8920515,4.55029408 C13.173002,5.02577831 13.0153013,5.63898983 12.539817,5.91994035 L6.47759481,9.50194035 C6.00211058,9.78289087 5.38889906,9.62519015 5.10794854,9.14970592 C4.82699802,8.67422169 4.98469874,8.06101017 5.46018297,7.78005965 L11.5224052,4.19805965 Z"></path> </g> </svg>';
				$output .= '</div>';
			}
		}

		if( $cart == "true" ) {
			if( $header_cart == "1" ) {
				if( function_exists( 'is_woocommerce' ) ) { 
					global $woocommerce;
					$output .= '<div class="gt-icon gt-basket-icon" data-basket="' . esc_attr( $woocommerce->cart->cart_contents_count ) . '">';
						$output .= '<a href="' . wc_get_cart_url() . '" title="' . esc_html__( 'View your shopping cart', 'bianco' ) . '">';
							$output .= '<svg viewBox="0 0 20 20" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g> <path d="M1,2 C0.44771525,2 0,1.55228475 0,1 C0,0.44771525 0.44771525,0 1,0 L4.27272727,0 C4.75265092,0 5.1649005,0.340944882 5.25496179,0.812342458 L5.91855496,4.28571429 L19,4.28571429 C19.6239893,4.28571429 20.0955837,4.85090525 19.9838324,5.4648061 L18.6734067,12.6634183 C18.4295325,13.9497165 17.3230949,14.8828122 16.0545455,14.8571429 L8.12189049,14.8569414 C6.83326876,14.8828122 5.72683115,13.9497165 5.48322003,12.6648004 L4.11688022,5.51312344 C4.11095017,5.48762304 4.10599587,5.46174987 4.1020585,5.43554378 L3.44569214,2 L1,2 Z M7.44795211,12.2908674 C7.51292025,12.6335376 7.7853595,12.8632947 8.10181818,12.8571429 L16.0746178,12.8573443 C16.3710041,12.8632947 16.6434434,12.6335376 16.7070767,12.298051 L17.8015318,6.28571429 L6.30065812,6.28571429 L7.44795211,12.2908674 Z M16.5454545,20 C15.5306269,20 14.7272727,19.1583909 14.7272727,18.1428571 C14.7272727,17.1273234 15.5306269,16.2857143 16.5454545,16.2857143 C17.5602822,16.2857143 18.3636364,17.1273234 18.3636364,18.1428571 C18.3636364,19.1583909 17.5602822,20 16.5454545,20 Z M7.54545455,20 C6.53062686,20 5.72727273,19.1583909 5.72727273,18.1428571 C5.72727273,17.1273234 6.53062686,16.2857143 7.54545455,16.2857143 C8.56028223,16.2857143 9.36363636,17.1273234 9.36363636,18.1428571 C9.36363636,19.1583909 8.56028223,20 7.54545455,20 Z"></path> </g> </svg>';
						$output .= '</a>';
					$output .= '</div>';
				}
			}
		}

		if( $menu == "true" ) {
			if( $header_menu == "1" ) {
				$output .= '<div class="gt-icon gt-mobile-menu--open">';
					$output .= '<svg viewBox="0 0 20 14" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g> <path d="M1,2 C0.44771525,2 0,1.55228475 0,1 C0,0.44771525 0.44771525,0 1,0 L19,0 C19.5522847,0 20,0.44771525 20,1 C20,1.55228475 19.5522847,2 19,2 L1,2 Z M1,8 C0.44771525,8 0,7.55228475 0,7 C0,6.44771525 0.44771525,6 1,6 L19,6 C19.5522847,6 20,6.44771525 20,7 C20,7.55228475 19.5522847,8 19,8 L1,8 Z M1,14 C0.44771525,14 0,13.5522847 0,13 C0,12.4477153 0.44771525,12 1,12 L19,12 C19.5522847,12 20,12.4477153 20,13 C20,13.5522847 19.5522847,14 19,14 L1,14 Z"></path> </g> </svg>';
				$output .= '</div>';
			}
		}

		return $output;
	}



	/*======
	*
	* Fixed Header
	*
	======*/
	function bianco_fixed_header() {
		$output = "";
		$fixed_header = get_theme_mod( 'bianco_header_fixed', '1' );

		if( $fixed_header == "1" ) {
			$output .= '<div class="gt-header-fixed">';
				$output .= '<div class="gt-line"></div>';
				$output .= '<div class="container">';
					$output .= bianco_navbar_style_1();
				$output .= '</div>';
			$output .= '</div>';
		}

		return $output;
	}


	/*======
	*
	* Header Location
	*
	======*/
	function bianco_header_location() {
		$output = '<div class="gt-title">';
			if( is_category() ) {
				$title = esc_html__( 'Category', 'bianco' );
			} elseif( is_tag() ) {
				$title = esc_html__( 'Tag', 'bianco' );
			} elseif( is_search() ) {
				$title = esc_html__( 'Search', 'bianco' );
			} elseif( is_author() ) {
				$title = esc_html__( 'Author', 'bianco' );
			} elseif( is_home() ) {
				$title = esc_html__( 'Home', 'bianco' );
			} elseif( is_404() ) {
				$title = esc_html__( '404 Page', 'bianco' );
			} elseif( is_single() ) {
				$title = esc_html__( 'Blog', 'bianco' );
			} elseif( is_page() ) {
				$title = esc_html__( 'Page', 'bianco' );
			} elseif( is_attachment() ) {
				$title = esc_html__( 'Attachment', 'bianco' );
			} elseif(  is_post_type_archive() ) {
				$title = esc_html__( 'Archive', 'bianco' );
			} elseif(  is_tax() ) {
				$title = esc_html__( 'Taxonomy', 'bianco' );
			} else {
				$title = esc_html__( 'Archive', 'bianco' );
			}
			$output .= $title;
		$output .= '</div>';
		return $output;
	}



	/*======
	*
	* Header
	*
	======*/
	function bianco_header() {
		$header_status = get_theme_mod( 'bianco_header_status', '1' );
		$header_status_default = get_theme_mod( 'bianco_header_status', '1' );
		$header_style = get_theme_mod( 'bianco_header_style', 'style-1' );
		$header_style_default = get_theme_mod( 'bianco_header_style', 'style-1' );

		if ( !$header_status_default == '' or $header_status_default == '1' ) {
			/*====== Post & Page Header Selector ======*/
			if ( is_page() or is_single() ) {
				global $post;
				$header_style = get_post_meta( $post->ID, 'header-style', true );
				if( empty( $header_style ) ) {
					$header_style = $header_style_default;
				}
			} else {
				$header_style = $header_style_default;
			}



			/*====== Header Styles ======*/
				/*====== Style 1 ======*/
				function bianco_navbar_style_1() {
					$output = '<nav class="gt-navbar">';
						$output .= wp_nav_menu(
							array(
								'menu' => 'main-menu',
								'theme_location' => 'main-menu',
								'depth' => 5,
								'container' => 'ul',
								'menu_class' => 'd-flex align-items-center justify-content-start',
								'fallback_cb' => 'bianco_walker::fallback',
								'walker' => new bianco_walker(),
								'echo' => false
							)
						);
					$output .= '</nav>';

					return $output;
				}



			/*====== Header Styles ======*/
				/*====== Style 1 ======*/
				function bianco_header_style_1() {
					$output = "";

					$header_status = get_theme_mod( 'bianco_header_status', '1' );
					$header_fixed = get_theme_mod( 'bianco_header_fixed', '1' );
					$header_social_media = get_theme_mod( 'bianco_header_social_media', '1' );
					$header_search = get_theme_mod( 'bianco_header_search', '1' );
					$header_cart = get_theme_mod( 'bianco_header_cart', '1' );
					$header_menu = get_theme_mod( 'bianco_header_menu', '1' );
					$header_location = get_theme_mod( 'bianco_header_location', '1' );

					$output .= '<header class="gt-header gt-style-1">';
						$output .= '<div class="gt-line"></div>';
						$output .= '<div class="gt-inner">';
							$output .= '<div class="container">';
								$output .= '<div class="gt-logo">';
										$output .= bianco_site_logo();
								$output .= '</div>';
								$output .= '<div class="gt-content">';
									$output .= '<div class="gt-box">';
										if( $header_menu == "1" or $header_location == "1" ) {
											$output .= '<div class="gt-navbar-box d-flex align-items-center justify-content-start">';
												if( $header_menu == "1" ) {
													$output .= '<div class="gt-icons d-flex align-items-center justify-content-end">';
														$output .= bianco_header_elements( $social = "false", $cart = "false", $menu = "true" );
													$output .= '</div>';

													$output .= '<div class="gt-line"></div>';
												}

												if( $header_location == "1" ) {
													$output .= bianco_header_location();
												}
											$output .= '</div>';
										}
									$output .= '</div>';

									if( $header_social_media == "1" or $header_cart == "1" or $header_search == "1"  ) {
										$output .= '<div class="gt-box d-flex align-items-center justify-content-end">';
											if( $header_search == "1" ) {
												$output .= '<div class="gt-search">';
													$output .= '<span><svg viewBox="0 0 20 20" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g> <path d="M19.7071068,18.2928932 C20.0976311,18.6834175 20.0976311,19.3165825 19.7071068,19.7071068 C19.3165825,20.0976311 18.6834175,20.0976311 18.2928932,19.7071068 L13.9428932,15.3571068 C13.5523689,14.9665825 13.5523689,14.3334175 13.9428932,13.9428932 C14.3334175,13.5523689 14.9665825,13.5523689 15.3571068,13.9428932 L19.7071068,18.2928932 Z M9,18 C4.02943725,18 0,13.9705627 0,9 C0,4.02943725 4.02943725,0 9,0 C13.9705627,0 18,4.02943725 18,9 C18,13.9705627 13.9705627,18 9,18 Z M9,16 C12.8659932,16 16,12.8659932 16,9 C16,5.13400675 12.8659932,2 9,2 C5.13400675,2 2,5.13400675 2,9 C2,12.8659932 5.13400675,16 9,16 Z"></path> </g> </svg></span>';
													$output .= bianco_search_form( $button = "false", $placeholder = esc_html__( 'Search', 'bianco' ) );
												$output .= '</div>';
											}

											if( $header_social_media == "1" or $header_cart == "1" ) {
												$output .= '<div class="gt-icons d-flex align-items-center justify-content-end">';
													$output .= bianco_header_elements( $social = "true", $cart = "true", $menu = "false" );
												$output .= '</div>';
											}
										$output .= '</div>';
									}
								$output .= '</div>';
							$output .= '</div>';
						$output .= '</div>';
					$output .= '</header>';

					return $output;
				}



				/*====== Style 2 ======*/
				function bianco_header_style_2() {
					$output = "";

					$header_status = get_theme_mod( 'bianco_header_status', '1' );
					$header_fixed = get_theme_mod( 'bianco_header_fixed', '1' );
					$header_social_media = get_theme_mod( 'bianco_header_social_media', '1' );
					$header_search = get_theme_mod( 'bianco_header_search', '1' );
					$header_cart = get_theme_mod( 'bianco_header_cart', '1' );
					$header_menu = get_theme_mod( 'bianco_header_menu', '1' );
					$header_location = get_theme_mod( 'bianco_header_location', '1' );

					$output .= '<header class="gt-header gt-style-2">';
						$output .= '<div class="gt-line"></div>';
						$output .= '<div class="gt-inner">';
							$output .= '<div class="container">';
								$output .= '<div class="gt-logo">';
										$output .= bianco_site_logo();
								$output .= '</div>';
								$output .= '<div class="gt-content">';
									$output .= '<div class="gt-box">';
										$output .= '<nav class="gt-navbar">';
											$output .= bianco_navbar_style_1();
										$output .= '</nav>';
									$output .= '</div>';

									if( $header_social_media == "1" or $header_cart == "1" or $header_search == "1"  ) {
										$output .= '<div class="gt-box d-flex align-items-center justify-content-end">';
											if( $header_search == "1" ) {
												$output .= '<div class="gt-search">';
													$output .= '<span><svg viewBox="0 0 20 20" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g> <path d="M19.7071068,18.2928932 C20.0976311,18.6834175 20.0976311,19.3165825 19.7071068,19.7071068 C19.3165825,20.0976311 18.6834175,20.0976311 18.2928932,19.7071068 L13.9428932,15.3571068 C13.5523689,14.9665825 13.5523689,14.3334175 13.9428932,13.9428932 C14.3334175,13.5523689 14.9665825,13.5523689 15.3571068,13.9428932 L19.7071068,18.2928932 Z M9,18 C4.02943725,18 0,13.9705627 0,9 C0,4.02943725 4.02943725,0 9,0 C13.9705627,0 18,4.02943725 18,9 C18,13.9705627 13.9705627,18 9,18 Z M9,16 C12.8659932,16 16,12.8659932 16,9 C16,5.13400675 12.8659932,2 9,2 C5.13400675,2 2,5.13400675 2,9 C2,12.8659932 5.13400675,16 9,16 Z"></path> </g> </svg></span>';
													$output .= bianco_search_form( $button = "false", $placeholder = esc_html__( 'Search', 'bianco' ) );
												$output .= '</div>';
											}

											if( $header_social_media == "1" or $header_cart == "1" ) {
												$output .= '<div class="gt-icons d-flex align-items-center justify-content-end">';
													$output .= bianco_header_elements( $social = "true", $cart = "true", $menu = "false" );
												$output .= '</div>';
											}
										$output .= '</div>';
									}
								$output .= '</div>';
							$output .= '</div>';
						$output .= '</div>';
					$output .= '</header>';

					return $output;
				}



				/*====== Style 2 ======*/
				function bianco_header_style_3() {
					$output = "";

					$header_status = get_theme_mod( 'bianco_header_status', '1' );
					$header_fixed = get_theme_mod( 'bianco_header_fixed', '1' );
					$header_social_media = get_theme_mod( 'bianco_header_social_media', '1' );
					$header_search = get_theme_mod( 'bianco_header_search', '1' );
					$header_cart = get_theme_mod( 'bianco_header_cart', '1' );
					$header_menu = get_theme_mod( 'bianco_header_menu', '1' );
					$header_location = get_theme_mod( 'bianco_header_location', '1' );

					$output .= '<header class="gt-header gt-style-3">';
						$output .= '<div class="gt-line"></div>';
						$output .= '<div class="gt-inner">';
							$output .= '<div class="container">';
								$output .= '<div class="gt-content">';
									if( $header_search == "1" or $header_social_media == "1" ) {
										$output .= '<div class="gt-box d-flex align-items-center justify-content-end">';
											if( $header_search == "1" ) {
												$output .= '<div class="gt-search">';
													$output .= '<span><svg viewBox="0 0 20 20" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g> <path d="M19.7071068,18.2928932 C20.0976311,18.6834175 20.0976311,19.3165825 19.7071068,19.7071068 C19.3165825,20.0976311 18.6834175,20.0976311 18.2928932,19.7071068 L13.9428932,15.3571068 C13.5523689,14.9665825 13.5523689,14.3334175 13.9428932,13.9428932 C14.3334175,13.5523689 14.9665825,13.5523689 15.3571068,13.9428932 L19.7071068,18.2928932 Z M9,18 C4.02943725,18 0,13.9705627 0,9 C0,4.02943725 4.02943725,0 9,0 C13.9705627,0 18,4.02943725 18,9 C18,13.9705627 13.9705627,18 9,18 Z M9,16 C12.8659932,16 16,12.8659932 16,9 C16,5.13400675 12.8659932,2 9,2 C5.13400675,2 2,5.13400675 2,9 C2,12.8659932 5.13400675,16 9,16 Z"></path> </g> </svg></span>';
													$output .= bianco_search_form( $button = "false", $placeholder = esc_html__( 'Search', 'bianco' ) );
												$output .= '</div>';
											}
												
											if( $header_social_media == "1" ) {
												$output .= '<div class="gt-icons d-flex align-items-center justify-content-end">';
													$output .= bianco_header_elements( $social = "true", $cart = "false", $menu = "false" );
												$output .= '</div>';
											}
										$output .= '</div>';
									}
								$output .= '</div>';

								$output .= '<div class="gt-logo">';
										$output .= bianco_site_logo();
								$output .= '</div>';

								$output .= '<div class="gt-content">';
									if( $header_cart == "1" or $header_menu == "1"  ) {
										$output .= '<div class="gt-box d-flex align-items-center justify-content-end">';
											if( $header_social_media == "1" or $header_cart == "1" ) {
												$output .= '<div class="gt-icons d-flex align-items-center justify-content-end">';
													$output .= bianco_header_elements( $social = "false", $cart = "true", $menu = "true" );
												$output .= '</div>';
											}
										$output .= '</div>';
									}
								$output .= '</div>';
							$output .= '</div>';
						$output .= '</div>';
					$output .= '</header>';

					return $output;
				}



			/*====== Header Style Selector ======*/
			if( $header_status == '1' ) {
				if( $header_style == "style-2" ) {
					$header_output = bianco_header_style_2();
				} elseif( $header_style == "style-3" ) {
					$header_output = bianco_header_style_3();
				} else {
					$header_output = bianco_header_style_1();
				}

				return $header_output;
			}

		}
	}



	/*======
	*
	* Mobile Header
	*
	======*/
	function bianco_mobile_header() {
		$output = '<header class="gt-header gt-mobile-header">';
			$output .= '<div class="gt-line"></div>';
			$output .= '<div class="gt-inner">';
				$output .= '<div class="container">';
					$output .= '<div class="gt-logo">';
						$output .= bianco_site_logo();
					$output .= '</div>';
					$output .= '<div class="gt-content">';
						$output .= '<div class="gt-box d-flex align-items-center justify-content-end">';
							$output .= '<div class="gt-icons d-flex align-items-center justify-content-end">';
								$output .= '<div class="gt-icon">';
									$output .= '<svg viewBox="0 0 20 20" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g> <path d="M1,2 C0.44771525,2 0,1.55228475 0,1 C0,0.44771525 0.44771525,0 1,0 L4.27272727,0 C4.75265092,0 5.1649005,0.340944882 5.25496179,0.812342458 L5.91855496,4.28571429 L19,4.28571429 C19.6239893,4.28571429 20.0955837,4.85090525 19.9838324,5.4648061 L18.6734067,12.6634183 C18.4295325,13.9497165 17.3230949,14.8828122 16.0545455,14.8571429 L8.12189049,14.8569414 C6.83326876,14.8828122 5.72683115,13.9497165 5.48322003,12.6648004 L4.11688022,5.51312344 C4.11095017,5.48762304 4.10599587,5.46174987 4.1020585,5.43554378 L3.44569214,2 L1,2 Z M7.44795211,12.2908674 C7.51292025,12.6335376 7.7853595,12.8632947 8.10181818,12.8571429 L16.0746178,12.8573443 C16.3710041,12.8632947 16.6434434,12.6335376 16.7070767,12.298051 L17.8015318,6.28571429 L6.30065812,6.28571429 L7.44795211,12.2908674 Z M16.5454545,20 C15.5306269,20 14.7272727,19.1583909 14.7272727,18.1428571 C14.7272727,17.1273234 15.5306269,16.2857143 16.5454545,16.2857143 C17.5602822,16.2857143 18.3636364,17.1273234 18.3636364,18.1428571 C18.3636364,19.1583909 17.5602822,20 16.5454545,20 Z M7.54545455,20 C6.53062686,20 5.72727273,19.1583909 5.72727273,18.1428571 C5.72727273,17.1273234 6.53062686,16.2857143 7.54545455,16.2857143 C8.56028223,16.2857143 9.36363636,17.1273234 9.36363636,18.1428571 C9.36363636,19.1583909 8.56028223,20 7.54545455,20 Z"></path> </g> </svg>';
								$output .= '</div>';
								$output .= '<div class="gt-icon gt-mobile-menu--open">';
									$output .= '<svg viewBox="0 0 20 14" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g> <path d="M1,2 C0.44771525,2 0,1.55228475 0,1 C0,0.44771525 0.44771525,0 1,0 L19,0 C19.5522847,0 20,0.44771525 20,1 C20,1.55228475 19.5522847,2 19,2 L1,2 Z M1,8 C0.44771525,8 0,7.55228475 0,7 C0,6.44771525 0.44771525,6 1,6 L19,6 C19.5522847,6 20,6.44771525 20,7 C20,7.55228475 19.5522847,8 19,8 L1,8 Z M1,14 C0.44771525,14 0,13.5522847 0,13 C0,12.4477153 0.44771525,12 1,12 L19,12 C19.5522847,12 20,12.4477153 20,13 C20,13.5522847 19.5522847,14 19,14 L1,14 Z"></path> </g> </svg>';
								$output .= '</div>';
							$output .= '</div>';
						$output .= '</div>';
					$output .= '</div>';
				$output .= '</div>';
			$output .= '</div>';
		$output .= '</header>';

		$output .= '<div class="gt-mobile-menu">';
			$output .= '<div class="gt-mobile-menu--close"></div>';
			$output .= '<div class="gt-mobile-menu--inner">';
				$output .= '<div class="scroll-pane">';
					$output .= '<div class="gt-mobile-menu-logo">';
						$output .= '<div class="gt-logo">';
							$output .= bianco_site_logo();
						$output .= '</div>';

						$output .= '<div class="gt-icon">';
							$output .= '<svg viewBox="0 0 14 14" version="1.1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"> <g> <path d="M7,5.58578644 L12.2928932,0.292893219 C12.6834175,-0.0976310729 13.3165825,-0.0976310729 13.7071068,0.292893219 C14.0976311,0.683417511 14.0976311,1.31658249 13.7071068,1.70710678 L8.41421356,7 L13.7071068,12.2928932 C14.0976311,12.6834175 14.0976311,13.3165825 13.7071068,13.7071068 C13.3165825,14.0976311 12.6834175,14.0976311 12.2928932,13.7071068 L7,8.41421356 L1.70710678,13.7071068 C1.31658249,14.0976311 0.683417511,14.0976311 0.292893219,13.7071068 C-0.0976310729,13.3165825 -0.0976310729,12.6834175 0.292893219,12.2928932 L5.58578644,7 L0.292893219,1.70710678 C-0.0976310729,1.31658249 -0.0976310729,0.683417511 0.292893219,0.292893219 C0.683417511,-0.0976310729 1.31658249,-0.0976310729 1.70710678,0.292893219 L7,5.58578644 Z"></path> </g> </svg>';
						$output .= '</div>';
					$output .= '</div>';
					$output .= '<nav class="gt-mobile-menu-navbar">';
						$output .= wp_nav_menu(
							array(
								'menu' => 'main-menu',
								'theme_location' => 'main-menu',
								'depth' => 5,
								'container' => 'ul',
								'fallback_cb' => 'bianco_walker::fallback',
								'walker' => new bianco_walker(),
								'echo' => false
							)
						);
					$output .= '</nav>';
				$output .= '</div>';
			$output .= '</div>';
		$output .= '</div>';

		return $output;
	}



	/*======
	*
	* Footer
	*
	======*/
	function bianco_footer() {
		$output = "";
		$footer_status = get_theme_mod( 'bianco_footer_status', '1' );
		$footer_menu = get_theme_mod( 'bianco_footer_menu', '1' );
		$footer_social_media = get_theme_mod( 'bianco_footer_social_media', '1' );
		$copyright_text = get_theme_mod( 'bianco_copyright_text' );

		if( $footer_status == '1' ) {
			$output .= '<footer class="gt-footer">';
				if( $footer_social_media == "1" ) {
					$output .= '<div class="gt-footer-top">';
						$output .= '<div class="container">';
							$output .= bianco_social_media_sites();
						$output .= '</div>';
					$output .= '</div>';
				}

				if( !empty( $copyright_text ) or $footer_menu == "1" ) {
					$output .= '<div class="gt-footer-bottom">';
						$output .= '<div class="container">';
							if( !empty( $copyright_text ) ) {
								$output .= '<div class="gt-box">';
									$output .= '<span>' . get_theme_mod( 'bianco_copyright_text' ) . '</span>';
								$output .= '</div>';
							}

							if( $footer_menu == "1" ) {
								$output .= '<div class="gt-box">';
									$output .= '<nav class="gt-navbar">';
										$output .= wp_nav_menu(
											array(
												'menu' => 'footer-menu',
												'theme_location' => 'footer-menu',
												'depth' => 1,
												'menu_class' => 'd-flex align-items-center justify-content-start',
												'fallback_cb' => 'bianco_walker::fallback',
												'walker' => new bianco_walker(),
												'echo' => false
											)
										);
									$output .= '</nav>';
								$output .= '</div>';
							}
						$output .= '</div>';
					$output .= '</div>';
				}
			$output .= '</footer>';
		}

		return $output;
	}



	/*======
	*
	* Post Styles
	*
	======*/
	function bianco_post_style_1( $post = "", $image = "", $excerpt = "", $read_more = "", $category = "", $date = "", $comment = "" ) {
		$output = "";

		if( !empty( $post ) ) {
			$output .= '<div class="gt-post-item">';
				if( $image == "true" ) {
					if ( has_post_thumbnail( $post ) ) {
						$image_url = wp_get_attachment_image_src( get_post_thumbnail_id( $post ), 'bianco-post-1' );
						if( !empty( $image_url ) ) {
							if ( is_sticky( $post ) ) {
								$output .= '<div class="gt-image sticky-post" data-name="' . esc_html__( 'Stick Post', 'bianco' ) . '">';
							} else {
								$output .= '<div class="gt-image">';
							}
								$output .= '<img src="' . esc_url( $image_url[0] ) . '" alt="' . the_title_attribute( array( 'echo' => 0, 'post' => $post ) ) . '" />';

								if( $read_more == 'true' ) {
									$output .= '<a href="' . get_the_permalink( $post ) . '" title="' . esc_html__( 'Read More', 'bianco' ) . '"><span>' . esc_html__( 'Read More', 'bianco' ) . '</span></a>';
								}
							$output .= '</div>';
						}
					}
				}

				$output .= '<div class="gt-content">';
					if( $category == "true" ) {
						if ( !empty( get_the_category_list( '', '', $post ) ) ) {
							$output .= '<span>';
								$output .= get_the_category_list( '', '', $post );
							$output .= '</span>';
						}
					}

					$output .= '<h2><a href="' . get_the_permalink( $post ) . '" title="' . the_title_attribute( array( 'echo' => 0, 'post' => $post ) ) . '">' . get_the_title( $post ) . '</a></h2>';

					if( $excerpt == 'true' ) {
						$summary = get_the_excerpt();
						if( !empty( $summary ) ) {
							$output .= '<p>' . get_the_excerpt() . '</p>';
						}
					}

					if( $comment == "true" or $date == "true" ) {
						$output .= '<ul>';
							if( $comment == "true" ) {
								if ( comments_open() ) {
									$output .= '<li>';
										$num_comments = get_comments_number( $post );
										if ( $num_comments == 0 ) {
											$comments = esc_html__( '0 Comment', 'bianco' );
										} elseif ( $num_comments > 1 ) {
											$comments = $num_comments . ' ' . esc_html__( 'Comments', 'bianco' );
										} else {
											$comments = esc_html__( '1 Comment', 'bianco' );
										}
										$output .= $comments;
									$output .= '</li>';
								}
							}

							if( $date == "true" ) {
								$output .= '<li>';
									$output .= get_the_time( get_option( 'date_format' ), $post );
								$output .= '</li>';
							}
						$output .= '</ul>';
					}
				$output .= '</div>';
			$output .= '</div>';
		}

		return $output;
	}

	function bianco_post_style_2( $post = "", $image = "", $excerpt = "", $read_more = "", $category = "", $date = "", $comment = "" ) {
		$output = "";

		if( !empty( $post ) ) {
			$output .= '<div class="gt-post-item">';
				if( $image == "true" ) {
					if ( has_post_thumbnail( $post ) ) {
						$image_url = wp_get_attachment_image_src( get_post_thumbnail_id( $post ), 'bianco-post-2' );
						if( !empty( $image_url ) ) {
							if ( is_sticky( $post ) ) {
								$output .= '<div class="gt-image sticky-post" data-name="' . esc_html__( 'Stick Post', 'bianco' ) . '">';
							} else {
								$output .= '<div class="gt-image">';
							}
								$output .= '<img src="' . esc_url( $image_url[0] ) . '" alt="' . the_title_attribute( array( 'echo' => 0, 'post' => $post ) ) . '" />';

								if( $read_more == 'true' ) {
									$output .= '<a href="' . get_the_permalink( $post ) . '" title="' . esc_html__( 'Read More', 'bianco' ) . '" class="gt-btn gt-btn-dark" role="button">' . esc_html__( 'Read More', 'bianco' ) . '</a>';
								}
							$output .= '</div>';
						}
					}
				}

				$output .= '<div class="gt-content">';
					if( $category == "true" ) {
						if ( !empty( get_the_category_list( '', '', $post ) ) ) {
							$output .= '<span>';
								$output .= get_the_category_list( '', '', $post );
							$output .= '</span>';
						}
					}

					$output .= '<h2><a href="' . get_the_permalink( $post ) . '" title="' . the_title_attribute( array( 'echo' => 0, 'post' => $post ) ) . '">' . get_the_title( $post ) . '</a></h2>';

					if( $excerpt == 'true' ) {
						$summary = get_the_excerpt();
						if( !empty( $summary ) ) {
							$output .= '<p>' . get_the_excerpt() . '</p>';
						}
					}

					if( $comment == "true" or $date == "true" ) {
						$output .= '<ul>';
							if( $comment == "true" ) {
								if ( comments_open() ) {
									$output .= '<li>';
										$num_comments = get_comments_number( $post );
										if ( $num_comments == 0 ) {
											$comments = esc_html__( '0 Comment', 'bianco' );
										} elseif ( $num_comments > 1 ) {
											$comments = $num_comments . ' ' . esc_html__( 'Comments', 'bianco' );
										} else {
											$comments = esc_html__( '1 Comment', 'bianco' );
										}
										$output .= $comments;
									$output .= '</li>';
								}
							}

							if( $date == "true" ) {
								$output .= '<li>';
									$output .= get_the_time( get_option( 'date_format' ), $post );
								$output .= '</li>';
							}
						$output .= '</ul>';
					}
				$output .= '</div>';
			$output .= '</div>';
		}

		return $output;
	}

	function bianco_post_style_3( $post = "", $read_more = "", $category = "", $date = "", $comment = "" ) {
		$output = "";

		if( !empty( $post ) ) {
			$output .= '<div class="gt-post-item">';
				$output .= '<div class="container">';

					if( $date == "true" ) {
						$output .= '<span>';
							$output .= get_the_time( get_option( 'date_format' ), $post );
						$output .= '</span>';
					}

					if ( is_sticky( $post ) ) {
						$output .= '<div class="gt-content sticky-post" data-name="' . esc_html__( 'Sticky Post', 'bianco' ) . '">';
					} else {
						$output .= '<div class="gt-content">';
					}
						$output .= '<h2><a href="' . get_the_permalink( $post ) . '" title="' . the_title_attribute( array( 'echo' => 0, 'post' => $post ) ) . '">' . get_the_title( $post ) . '</a></h2>';

						if( $comment == "true" or $category == "true" ) {
							$output .= '<ul>';
								if( $comment == "true" ) {
									if ( comments_open() ) {
										$output .= '<li>';
											$num_comments = get_comments_number( $post );
											if ( $num_comments == 0 ) {
												$comments = esc_html__( '0 Comment', 'bianco' );
											} elseif ( $num_comments > 1 ) {
												$comments = $num_comments . ' ' . esc_html__( 'Comments', 'bianco' );
											} else {
												$comments = esc_html__( '1 Comment', 'bianco' );
											}
											$output .= $comments;
										$output .= '</li>';
									}
								}

								if( $category == "true" ) {
									if ( !empty( get_the_category_list( '', '', $post ) ) ) {
										$output .= '<li>';
											$output .= get_the_category_list( '', '', $post );
										$output .= '</li>';
									}
								}
							$output .= '</ul>';
						}
					$output .= '</div>';

					if( $read_more == 'true' ) {
						$output .= '<a href="' . get_the_permalink( $post ) . '" title="' . esc_html__( 'Read More', 'bianco' ) . '" class="gt-btn gt-btn-dark" role="button">' . esc_html__( 'Read More', 'bianco' ) . '</a>';
					}
				$output .= '</div>';
			$output .= '</div>';
		}

		return $output;
	}



	/*======
	*
	* Post Listing
	*
	======*/
	function bianco_post_listing() {
		function bianco_post_list_style_1() {
			echo '<div class="gt-post-list gt-style-1 gt-columns gt-column-2">';
				while ( have_posts() ) : the_post();
					echo bianco_post_style_1( $post = get_the_ID(), $image = "true", $excerpt = "true", $read_more = "true", $category = "true", $date = "true", $comment = "true" );
				endwhile;
			echo '</div>';
		}

		function bianco_post_list_style_2() {
			echo '<div class="gt-post-list gt-style-2">';
				while ( have_posts() ) : the_post();
					echo bianco_post_style_2( $post = get_the_ID(), $image = "true", $excerpt = "true", $read_more = "true", $category = "true", $date = "true", $comment = "true" );
				endwhile;
			echo '</div>';
		}

		function bianco_post_list_style_3() {
			echo '<div class="gt-post-list gt-style-3">';
				while ( have_posts() ) : the_post();
					echo bianco_post_style_3( $post = get_the_ID(), $read_more = "true", $category = "true", $date = "true", $comment = "true" );
				endwhile;
			echo '</div>';
		}

		if( is_category() ) {
			$list_style = get_theme_mod( 'bianco_categories_post_style', 'style-1' );
		} elseif( is_tag() ) {
			$list_style = get_theme_mod( 'bianco_tags_post_style', 'style-1' );
		} elseif( is_search() ) {
			$list_style = get_theme_mod( 'bianco_searches_post_style', 'style-1' );
		} elseif( is_author() ) {
			$list_style = get_theme_mod( 'bianco_authors_post_style', 'style-1' );
		} else {
			$list_style = get_theme_mod( 'bianco_archives_post_style', 'style-1' );
		}

		if( $list_style == "style-2" ) {
			bianco_post_list_style_2();
		} elseif( $list_style == "style-3" ) {
			bianco_post_list_style_3();
		} else {
			bianco_post_list_style_1();
		}
	}



	/*======
	*
	* Post Navigation
	*
	======*/
	function bianco_post_navigation() {
		$prev_text = esc_html__( 'Previous', 'bianco' );
		$next_text = esc_html__( 'Next', 'bianco' );
		$prev_post = get_previous_post( false );
		$next_post = get_next_post( false );

		if( !empty( $prev_post ) or !empty( $next_post ) ) {
			$output = '<section class="gt-prevnext-article">';
				$output .= bianco_container_before( $extra_class = "", $echo = "false" );
					$output .= bianco_row_before( $extra_class = "", $echo = "false" );
						if( !empty( $prev_post ) ) {
							$output .= '<div class="col-5">';
								$output .= '<div class="gt-prevnext-item gt-left">';
									if ( has_post_thumbnail( $prev_post->ID ) ) {
										$image_url = wp_get_attachment_image_src( get_post_thumbnail_id( $prev_post->ID ), 'bianco-post-3' );
										if( !empty( $image_url ) ) {
											$output .= '<div class="gt-image">';
												$output .= '<img src="' . esc_url( $image_url[0] ) . '" alt="' . the_title_attribute( array( 'echo' => 0, 'post' => $prev_post->ID ) ) . '" />';
											$output .= '</div>';
										}
									}

									$output .= '<div class="gt-content">';
										$output .= '<span>' . esc_attr( 'Previous Post', 'bianco' ) . '</span>';
										$output .= '<h2><a href="' . get_permalink( $prev_post->ID ) . '" title="' . the_title_attribute( array( 'echo' => 0, 'post' => $prev_post->ID ) ) . '">' . get_the_title( $prev_post->ID ) . '</a></h2>';
									$output .= '</div>';
								$output .= '</div>';
							$output .= '</div>';
						}

						if( !empty( $prev_post ) and !empty( $next_post ) ) {
							$output .= '<div class="col-2">';
								$output .= '<div class="gt-allbloglist-btn">';
								$output .= '<a href="' . esc_url( home_url( '/' ) ) . '"><i class="fab fa-microsoft"></i></a>';
								$output .= '</div>';
							$output .= '</div>';
						}

						if( !empty( $next_post ) ) {
							$output .= '<div class="col-5">';
								$output .= '<div class="gt-prevnext-item gt-right">';
									if ( has_post_thumbnail( $next_post->ID ) ) {
										$image_url = wp_get_attachment_image_src( get_post_thumbnail_id( $next_post->ID ), 'bianco-post-3' );
										if( !empty( $image_url ) ) {
											$output .= '<div class="gt-image">';
												$output .= '<img src="' . esc_url( $image_url[0] ) . '" alt="' . the_title_attribute( array( 'echo' => 0, 'post' => $next_post->ID ) ) . '" />';
											$output .= '</div>';
										}
									}

									$output .= '<div class="gt-content">';
										$output .= '<span>' . esc_attr( 'Next Post', 'bianco' ) . '</span>';
										$output .= '<h2><a href="' . get_permalink( $next_post->ID ) . '" title="' . the_title_attribute( array( 'echo' => 0, 'post' => $next_post->ID ) ) . '">' . get_the_title( $next_post->ID ) . '</a></h2>';
									$output .= '</div>';
								$output .= '</div>';
							$output .= '</div>';
						}
					$output .= bianco_row_after();
				$output .= bianco_container_after();
			$output .= '</section>';
			return $output;
		}
	}



	/*======
	*
	* Related Posts
	*
	======*/
	function bianco_related_posts( $post = "" ) {
		$output = "";
		$tags = wp_get_post_tags( $post );
		$count = get_theme_mod( 'bianco_posts_related_posts_count', '3' );
		if ( !empty( $tags ) ) {
			$tag_ids = array();
			foreach( $tags as $individual_tag ) {
				$tag_ids[] = $individual_tag->term_id;
			}

			if( !empty( $tag_ids ) ) {
				$args = array(
					'tag__in' => $tag_ids,
					'post__not_in' => array( $post ),
					'post_status' => 'publish',
					'post_type' => 'post',
					'ignore_sticky_posts' => true,
					'posts_per_page' => $count
				);
				$wp_query = new wp_query( $args );
				if ( $wp_query->have_posts() ) {
					$output .= '<section class="gt-related-posts gt-section-spacing">';
						$output .= '<div class="container">';
							$output .= '<div class="gt-section-heading">';
								$output .= '<div class="gt-icon">';
									$output .= '<i class="fas fa-caret-right"></i>';
								$output .= '</div>';
								$output .= '<div class="gt-title">';
									$output .= '<span>' . esc_html__( 'Related News', 'bianco' ) . '</span>';
								$output .= '</div>';
							$output .= '</div>';
							$output .= '<div class="gt-post-list gt-style-3">';
								while( $wp_query->have_posts() ) {
									$wp_query->the_post();
									$output .= bianco_post_style_3( $post = get_the_ID(), $read_more = "true", $category = "false", $date = "true", $comment = "true" );
								}
							$output .= '</div>';
						$output .= '</div>';
					$output .= '</section>';
					return $output;
				}
				wp_reset_postdata();
			}
		}
	}



	/*======
	*
	* Blog in Page
	*
	======*/
	function bianco_blog_in_page() {
		if ( function_exists( 'rwmb_meta' ) ) {
			$output = "";
			$blog_list_style = rwmb_meta( 'blog-list-style' );
			$blog_list_column = rwmb_meta( 'blog-list-column' );
			$blog_list_post_style = rwmb_meta( 'blog-list-post-style' );
			$blog_list_status = rwmb_meta( 'blog-list-status' );
			$blog_pagination = rwmb_meta( 'blog-list-post-pagination' );
			$blog_categories = rwmb_meta( 'blog-list-categories' );
			$blog_count = rwmb_meta( 'blog-list-count' );
			$blog_exclude_posts = rwmb_meta( 'blog-list-exclude-posts' );
			$blog_tag = rwmb_meta( 'blog-list-tag' );
			$blog_order = rwmb_meta( 'blog-list-order' );
			$blog_order_type = rwmb_meta( 'blog-list-order-type' );

			if( $blog_list_status == "1" ) {

				/*====== Categories ======*/
				$cat_array = "";
				$include_categories_array = "";
				if( !empty( $blog_categories ) ) {
					$cat_array = array();
					foreach( $blog_categories as $blog_cat ) {
						if ( !empty( $blog_cat ) ) {
							$cat_array[] = $blog_cat->term_id;
						}
					}
				}

				if( !empty( $cat_array ) ) {
					$include_categories_array = array(
						'taxonomy' => 'category',
						'field' => 'term_id',
						'terms' => $cat_array,
						'operator' => 'IN',
					);
				}

				/*====== Tags ======*/
				$tag_array = "";
				$include_tags_array = "";
				if( !empty( $tags ) ) {
					$tag_array = array();
					foreach( $tags as $tag ) {
						if ( !empty( $tag ) ) {
							$tag_array[] = $tag->term_id;
						}
					}
				}

				if( !empty( $tag_array ) ) {
					$include_tags_array = array(
						'taxonomy' => 'post_tag',
						'field' => 'term_id',
						'terms' => $tag_array,
						'operator' => 'IN',
					);
				}

				/*====== Main Query ======*/
				$blog_arg = array(
					'posts_per_page' => $blog_count,
					'post_status' => 'publish',
					'tax_query' => array (
						'relation' => 'AND',
						$include_categories_array,
						$include_tags_array,
					)
				);

				/*====== Exclude Posts ======*/
				if( !empty( $blog_exclude_posts ) ) {
					$exclude_posts = $blog_exclude_posts;
					$exclude_posts = explode( ',', $exclude_posts );
				} else {
					$exclude_posts = "";
				}

				if( !empty( $exclude_posts ) ) {
					$extra_query = array(
						'post__not_in' => $exclude_posts,
					);
					$blog_arg = wp_parse_args( $blog_arg, $extra_query );
				}

				/*====== Order & Order By ======*/
				if( $blog_order == "ASC" ) {
					$order = "ASC";
				} else {
					$order = "DESC";
				}

				if( !empty( $order ) ) {
					$extra_query = array(
						'order' => $order,
					);
					$blog_arg = wp_parse_args( $blog_arg, $extra_query );
				}

				if( $blog_order_type == "popular-comment" ) {
					$order_by = "comment_count";
				} elseif( $blog_order_type == "id" ) {
					$order_by = "ID";
				} elseif( $blog_order_type == "title" ) {
					$order_by = "title";
				} elseif( $blog_order_type == "menu_order" ) {
					$order_by = "menu_order";
				} elseif( $blog_order_type == "rand" ) {
					$order_by = "rand";
				} elseif( $blog_order_type == "none" ) {
					$order_by = "none";
				} else {
					$order_by = "date";
				}

				if( !empty( $order_by ) ) {
					$extra_query = array(
						'orderby' => $order_by,
					);
					$blog_arg = wp_parse_args( $blog_arg, $extra_query );
				}

				/*====== Pagination ======*/
				if( $blog_pagination == "1" ) {
					$paged = is_front_page() ? get_query_var( 'page', 1 ) : get_query_var( 'paged', 1 );
					if( empty( $paged ) ) { $paged = 1; }

					$extra_query = array(
						'paged' => $paged,
					);
					$blog_arg = wp_parse_args( $blog_arg, $extra_query );
				}

				$wp_query = new WP_Query( $blog_arg );
				if( $wp_query->have_posts() ) {
					if( $blog_list_post_style == "style-1" ) {
						if( $blog_list_column == "column-1" ) {
							$column = "1";
						} elseif( $blog_list_column == "column-2" ) {
							$column = "2";
						} elseif( $blog_list_column == "column-3" ) {
							$column = "3";
						} else {
							$column = "4";
						}

						$output .= '<div class="gt-post-list gt-style-1 gt-columns gt-column-' . esc_attr( $column ) . '">';
							while ( $wp_query->have_posts() ) {
								$wp_query->the_post();
								$output .= bianco_post_style_1( $post = get_the_ID(), $image = "true", $excerpt = "true", $read_more = "true", $category = "true", $date = "true", $comment = "true" );
							}
							wp_reset_postdata();
						$output .= '</div>';
					} elseif( $blog_list_post_style == "style-2" ) {
						$output .= '<div class="gt-post-list gt-style-2">';
							while ( $wp_query->have_posts() ) {
								$wp_query->the_post();
								$output .= bianco_post_style_2( $post = get_the_ID(), $image = "true", $excerpt = "true", $read_more = "true", $category = "true", $date = "true", $comment = "true" );
							}
							wp_reset_postdata();
						$output .= '</div>';
					} else {
						$output .= '<div class="gt-post-list gt-style-3">';
							while ( $wp_query->have_posts() ) {
								$wp_query->the_post();
							$output .= bianco_post_style_3( $post = get_the_ID(), $read_more = "true", $category = "true", $date = "true", $comment = "true" );
							}
							wp_reset_postdata();
						$output .= '</div>';
					}

					if( $blog_pagination == "1" ) {
						$output .= bianco_element_pagination( $paged = $paged, $query = $wp_query );
					}
				}
			}

			return $output;
		}		
	}



	/*======
	*
	* Post Slider
	*
	======*/
	function bianco_post_slider() {
		if ( function_exists( 'rwmb_meta' ) ) {
			$slider_status = rwmb_meta( 'slider-status' );
			$slider_pagination = rwmb_meta( 'slider-pagination' );
			$slider_navigation = rwmb_meta( 'slider-navigation' );
			$slider_categories = rwmb_meta( 'slider-categories' );
			$slider_post_count = rwmb_meta( 'slider-post-count' );
			$slider_exclude_posts = rwmb_meta( 'slider-exclude-posts' );
			$slider_include_posts = rwmb_meta( 'slider-include-posts' );
			$slider_tags = rwmb_meta( 'slider-tag' );
			$slider_order = rwmb_meta( 'slider-order' );
			$slider_order_type = rwmb_meta( 'slider-order-type' );

			if( $slider_status == "1" ) {

				/*====== Slider Categories ======*/
				$slider_cat_array = "";
				$include_categories_array = "";
				if( !empty( $slider_categories ) ) {
					$slider_cat_array = array();
					foreach( $slider_categories as $slider_cat ) {
						if ( !empty( $slider_cat ) ) {
							$slider_cat_array[] = $slider_cat->term_id;
						}
					}
				}

				if( !empty( $slider_cat_array ) ) {
					$include_categories_array = array(
						'taxonomy' => 'category',
						'field' => 'term_id',
						'terms' => $slider_cat_array,
						'operator' => 'IN',
					);
				}

				/*====== Slider Tags ======*/
				$slider_tag_array = "";
				$include_tags_array = "";
				if( !empty( $slider_tags ) ) {
					$slider_tag_array = array();
					foreach( $slider_tags as $slider_tag ) {
						if ( !empty( $slider_tag ) ) {
							$slider_tag_array[] = $slider_tag->term_id;
						}
					}
				}

				if( !empty( $slider_tag_array ) ) {
					$include_tags_array = array(
						'taxonomy' => 'post_tag',
						'field' => 'term_id',
						'terms' => $slider_tag_array,
						'operator' => 'IN',
					);
				}

				/*====== Main Query ======*/
				$slider_arg = array(
					'posts_per_page' => $slider_post_count,
					'post_status' => 'publish',
					'ignore_sticky_posts' => true,
					'tax_query' => array (
						'relation' => 'AND',
						$include_categories_array,
						$include_tags_array,
					)
				);

				/*====== Exclude Posts ======*/
				if( !empty( $slider_exclude_posts ) ) {
					$exclude_posts = $slider_exclude_posts;
					$exclude_posts = explode( ',', $exclude_posts );
				} else {
					$exclude_posts = "";
				}

				if( !empty( $exclude_posts ) ) {
					$extra_query = array(
						'post__not_in' => $exclude_posts,
					);
					$slider_arg = wp_parse_args( $slider_arg, $extra_query );
				}

				/*====== Include Posts ======*/
				if( !empty( $slider_include_posts ) ) {
					$include_posts = $slider_include_posts;
					$include_posts = explode( ',', $include_posts );
				} else {
					$include_posts = "";
				}

				if( !empty( $include_posts ) ) {
					$extra_query = array(
						'post__in' => $include_posts,
					);
					$slider_arg = wp_parse_args( $slider_arg, $extra_query );
				}

				/*====== Order & Order By ======*/
				if( $slider_order == "ASC" ) {
					$order = "ASC";
				} else {
					$order = "DESC";
				}

				if( !empty( $order ) ) {
					$extra_query = array(
						'order' => $order,
					);
					$slider_arg = wp_parse_args( $slider_arg, $extra_query );
				}

				if( $slider_order_type == "popular-comment" ) {
					$order_by = "comment_count";
				} elseif( $slider_order_type == "id" ) {
					$order_by = "ID";
				} elseif( $slider_order_type == "title" ) {
					$order_by = "title";
				} elseif( $slider_order_type == "menu_order" ) {
					$order_by = "menu_order";
				} elseif( $slider_order_type == "rand" ) {
					$order_by = "rand";
				} elseif( $slider_order_type == "none" ) {
					$order_by = "none";
				} else {
					$order_by = "date";
				}

				if( !empty( $order_by ) ) {
					$extra_query = array(
						'orderby' => $order_by,
					);
					$slider_arg = wp_parse_args( $slider_arg, $extra_query );
				}

				$slider_wp_query = new WP_Query( $slider_arg );
				if( $slider_wp_query->have_posts() ) {
	?>
					<section class="gt-slider">
						<div class="gt-slider-top"></div>
						<div class="gt-container">
							<div class="gt-slider--swiper">
								<div class="swiper-container gt-swiper-slider" data-gt-speed="1000" data-gt-loop="true" data-gt-parallax="true" data-gt-direction="horizontal" data-gt-item="1" data-gt-item-space="0">
									<div class="swiper-wrapper">
										<?php while ( $slider_wp_query->have_posts() ) { ?>
											<?php $slider_wp_query->the_post(); ?>
											<div class="swiper-slide">
												<?php
													if ( has_post_thumbnail() ) {
														$image_url = wp_get_attachment_image_src( get_post_thumbnail_id( get_the_ID() ), 'bianco-page-banner-1' );
														if( !empty( $image_url ) ) {
															echo '<div class="swiper-slide--image" data-swiper-parallax-x="400" style="background-image: url(' . $image_url[0] . ')"></div>';
														}
													}
												?>
												<div class="swiper-slide--caption" data-swiper-parallax-x="600">
													<?php if ( !empty( get_the_category_list() ) ) { ?>
														<span>
															<?php echo get_the_category_list( '', '' ); ?>
														</span>
													<?php } ?>
													<h2><a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>"><?php the_title(); ?></a></h2>
													<ul>
														<?php
															if ( comments_open() ) {
																echo '<li class="comment">';
																	$num_comments = get_comments_number();
																	if ( $num_comments == 0 ) {
																		$comments = esc_html__( '0 Comment', 'bianco' );
																	} elseif ( $num_comments > 1 ) {
																		$comments = $num_comments . ' ' . esc_html__( 'Comments', 'bianco' );
																	} else {
																		$comments = esc_html__( '1 Comment', 'bianco' );
																	}
																	echo esc_attr( $comments );
																echo '</li>';
															}
														?>
														<li class="time">
															<?php the_time( get_option( 'date_format' ) ); ?>
														</li>
													</ul>
												</div>
											</div>
										<?php } ?>
										<?php wp_reset_postdata(); ?>
									</div>

									<?php if( $slider_navigation == "1" or $slider_pagination == "1" ) { ?>
										<div class="gt-slider-controls">
											<div class="container">
												<?php if( $slider_navigation == "1" ) { ?>
													<div class="gt-slider-button gt-slider-prev">
														<span class="text"><?php echo esc_html__( 'Prev', 'bianco' ); ?></span>
														<span class="line"></span>
													</div>
												<?php } ?>
												<?php if( $slider_pagination == "1" ) { ?>
													<div class="swiper-pagination"></div>
												<?php } ?>
												<?php if( $slider_navigation == "1" ) { ?>
													<div class="gt-slider-button gt-slider-next">
														<span class="line"></span>
														<span class="text"><?php echo esc_html__( 'Next', 'bianco' ); ?></span>
													</div>
												<?php } ?>
											</div>
										</div>
									<?php } ?>
								</div>
							</div>
						</div>
					</section>
		<?php
				}
			}
		}		
	}