<?php
/*======
*
* Typekit Fonts URLs
*
======*/
	function bianco_typekit_fonts_url() {
		$typekit_fonts = get_theme_mod( 'bianco_typekit_font_names' );
		$typekit_kit_id = get_theme_mod( 'bianco_typekit_kit_id' );
		if( !empty( $typekit_kit_id ) ) {
			wp_enqueue_script( 'bianco-typekit', 'https://use.typekit.net/'. esc_attr( $typekit_kit_id ) .'.js', array(), NULL, FALSE );
			wp_add_inline_script( 'bianco-typekit', 'try{Typekit.load({ async: true });}catch(e){}' );
		}
	}
	add_action( 'wp_enqueue_scripts', 'bianco_typekit_fonts_url' );



/*======
*
* Google Fonts URLs
*
======*/
	function bianco_google_fonts_url() {
		$custom_font_list = array();

		/*====== Customize Variables ======*/
		$latin_extended = get_theme_mod( 'bianco_typography_latin_extended' );
		$cyrillic_extended = get_theme_mod( 'bianco_typography_cyrillic_extended' );
		$greek_extended = get_theme_mod( 'bianco_typography_greek_extended' );
		$font_weights = get_theme_mod( 'bianco_font_weights' );

		/*====== Weights ======*/
		if( !empty( $font_weights ) ) {
			$weights = ':' . $font_weights;
		} else {
			$weights = ":100,100italic,200,200italic,300,300italic,400,400italic,500,500italic,600,600italic,700,700italic,800,800italic,900,900italic";			
		}

		/*====== Theme Fonts ======*/
		$main_font = get_theme_mod( 'bianco_typography_main_font' );
		$heading_font = get_theme_mod( 'bianco_typography_heading_font' );
		$content_font = get_theme_mod( 'bianco_typography_content_font' );

		if( !empty( $main_font ) ) {
			$custom_font_list[] = $main_font;
		} else {
			$custom_font_list[] = "Roboto";
		}

		if( !empty( $heading_font ) ) {
			$custom_font_list[] = $heading_font;
		} else {
			$custom_font_list[] = "Roboto";
		}

		if( !empty( $content_font ) ) {
			$custom_font_list[] = $content_font;
		} else {
			$custom_font_list[] = "Merriweather";
		}

		if( !empty( $custom_font_list ) ) {
			$custom_font_list = array_unique( $custom_font_list );
			$prefixed_array = preg_filter( '/$/', $weights, $custom_font_list );
			if( !empty( $prefixed_array ) ) {
				$prefixed_imp = implode( '|', $prefixed_array );
				$font_names = rtrim( $prefixed_imp, '|' );				
			}
		}

		/*====== Subsets ======*/
		$subsets = array( "latin" );
		if( !empty( $latin_extended ) or $latin_extended == "1" ) {
			$subsets[] = "latin-ext";
		}

		if( !empty( $cyrillic_extended ) or $cyrillic_extended == "1" ) {
			$subsets[] = "cyrillic";
			$subsets[] = "cyrillic-ext";
		}

		if( !empty( $greek_extended ) or $greek_extended == "1" ) {
			$subsets[] = "greek";
			$subsets[] = "greek-ext";
		}

		if( !empty( $subsets ) ) {
			$subset_list = rtrim( implode( ',', $subsets ), ',' );
		}

		/*====== Font URL ======*/
		$font_url = '';
		$font_url = add_query_arg( 'family', urlencode( $font_names . '&subset=' . $subset_list . '' ), "//fonts.googleapis.com/css" );

		return $font_url;
	}

	function bianco_fonts_scripts() {
		wp_enqueue_style( 'bianco-fonts', bianco_google_fonts_url(), array(), '1.0.0' );
	}
	add_action( 'wp_enqueue_scripts', 'bianco_fonts_scripts' );



/*======
*
* Typography Selector
*
======*/
	function bianco_font_selector( $class = "", $family = "", $default = "" ) {
		if( !empty( $class ) and !empty( $family ) or !empty( $default ) ) {
			if( !empty( $family ) and !empty( get_theme_mod( $family ) ) ) {
				$setting = get_theme_mod( $family );
			} else {
				$setting = $default;
			}

			if( $setting ) {
				$typekit_fonts = get_theme_mod( 'bianco_typekit_font_names' );
				$typekit_kit_id = get_theme_mod( 'bianco_typekit_kit_id' );
				if( !empty( $typekit_fonts ) and !empty( $typekit_kit_id ) ) {
					$setting = str_replace( ' ', '-', strtolower( $setting ) );
				}

				$custom_style = $class . "{ font-family: '" . $setting . "'; }";
				return $custom_style;
			}
		}
	}

	function bianco_custom_fonts() {
		wp_enqueue_style( 'bianco-custom', get_template_directory_uri() . '/include/assets/css/custom.css', array(), '1.0.0' );
		wp_add_inline_style( 'bianco-custom', bianco_font_selector( 'body, input, textarea, button, form, .button, .btn .gt-slider--swiper .gt-slider-controls, span.wpcf7-not-valid-tip, div.wpcf7-response-output, .gt-page-content .woocommerce, .woocommerce .comment-form, .woocommerce .gt-page-content', 'bianco_typography_main_font', 'Roboto' ) );
		wp_add_inline_style( 'bianco-custom', bianco_font_selector( 'h1, h2, h3, h4, h5, h6', 'bianco_typography_heading_font', 'Roboto' ) );
		wp_add_inline_style( 'bianco-custom', bianco_font_selector( '.gt-page-content, .woocommerce div.product .woocommerce-tabs .panel, .woocommerce-product-details__short-description', 'bianco_typography_content_font', 'Merriweather' ) );
	}
	add_action( 'wp_enqueue_scripts', 'bianco_custom_fonts' );



/*======
*
* Custom Selector
*
======*/
	function bianco_custom_selector( $class = "", $property = "", $setting = "", $measurement = '', $important = '' ) {
		if( !empty( $class ) and !empty( $setting ) ) {
			if( get_theme_mod( $setting ) ) {
				if( $important == "true" ) {
					$custom_style = $class . '{ ' . $property . ': ' . get_theme_mod( $setting ) . $measurement . ' !important; }';
				} else {
					$custom_style = $class . '{ ' . $property . ': ' . get_theme_mod( $setting ) . $measurement . '; }';					
				}
				return $custom_style;
			}
		}
	}

	function bianco_custom_selectors() {
		wp_enqueue_style( 'bianco-custom', get_template_directory_uri() . '/include/assets/css/custom.css', array(), '1.0.0' );

		wp_add_inline_style( 'bianco-custom', bianco_custom_selector( '.woocommerce .woocommerce-MyAccount-navigation ul li.is-active a, .woocommerce .woocommerce-MyAccount-navigation ul li.is-active a:visited, .woocommerce .woocommerce-MyAccount-navigation ul li a:hover, .woocommerce .woocommerce-MyAccount-navigation ul li a:focus, .woocommerce #respond input#submit.disabled:hover, .woocommerce #respond input#submit:disabled:hover, .woocommerce #respond input#submit:disabled[disabled]:hover, .woocommerce a.button.disabled:hover, .woocommerce a.button:disabled:hover, .woocommerce a.button:disabled[disabled]:hover, .woocommerce input.button.disabled:hover, .woocommerce input.button:disabled:hover, .woocommerce input.button:disabled[disabled]:hover, .woocommerce span.onsale, .cloux-header .cloux-navbar.style-1 .navbar-menu li .dropdown-menu, .gt-header .gt-basket-icon::before, .gt-post-list.gt-style-3 .gt-post-item .gt-btn:hover', 'background-color', 'bianco_main_color' ) );

		wp_add_inline_style( 'bianco-custom', bianco_custom_selector( '.woocommerce-error, .woocommerce-info, .woocommerce-message, .woocommerce .woocommerce-MyAccount-navigation ul li a, .woocommerce .woocommerce-MyAccount-navigation ul li a:visited, div.wpcf7-validation-errors, div.wpcf7-acceptance-missing', 'border-color', 'bianco_main_color' ) );

		wp_add_inline_style( 'bianco-custom', bianco_custom_selector( '.woocommerce .woocommerce-MyAccount-navigation ul li a, .woocommerce .woocommerce-MyAccount-navigation ul li a:visited, .woocommerce-error::before, .woocommerce-info::before, .woocommerce-message::before, .woocommerce div.product p.price, .woocommerce div.product span.price, .woocommerce ul.products li.product .price, span.wpcf7-not-valid-tip, a:hover, a:focus, .gt-navbar a:hover, .gt-slider .swiper-slide--caption span a, .gt-page-heading .gt-content span a, .gt-prevnext-article .gt-content span, .gt-post-list .gt-post-item span a, .gt-post-list.gt-style-3 .gt-post-item .gt-content ul li a, .gt-navbar ul ul li:hover > a, .gt-navbar ul li:hover > a', 'color', 'bianco_main_color' ) );

		wp_add_inline_style( 'bianco-custom', bianco_custom_selector( '.gt-icons .gt-icon:hover svg', 'fill', 'bianco_main_color' ) );

		wp_add_inline_style( 'bianco-custom', bianco_custom_selector( 'body', 'color', 'bianco_body_text_color' ) );

		wp_add_inline_style( 'bianco-custom', bianco_custom_selector( '.gt-header .gt-inner', 'background-color', 'bianco_header_background' ) );

		wp_add_inline_style( 'bianco-custom', bianco_custom_selector( '.gt-navbar a', 'color', 'bianco_header_menu_link_color' ) );

		wp_add_inline_style( 'bianco-custom', bianco_custom_selector( '.gt-navbar ul ul', 'background-color', 'bianco_header_dropdown_background' ) );

		wp_add_inline_style( 'bianco-custom', bianco_custom_selector( '.gt-widget .gt-widget--heading', 'background-color', 'bianco_widget_title_background' ) );

		wp_add_inline_style( 'bianco-custom', bianco_custom_selector( '.gt-widget .gt-widget--heading, .gt-widget .gt-widget--heading .gt-widget--title', 'color', 'bianco_widget_title_color' ) );

		wp_add_inline_style( 'bianco-custom', bianco_custom_selector( '.gt-section-heading', 'background-color', 'bianco_section_heading_background' ) );

		wp_add_inline_style( 'bianco-custom', bianco_custom_selector( '.gt-section-heading, .gt-section-heading .gt-title', 'color', 'bianco_section_heading_text_color' ) );

		wp_add_inline_style( 'bianco-custom', bianco_custom_selector( '.gt-page-content .gt-single-content', 'color', 'bianco_post_text_color' ) );

		wp_add_inline_style( 'bianco-custom', bianco_custom_selector( '.gt-post-tags ul li a:hover', 'background-color', 'bianco_post_tag_hover_background' ) );

		wp_add_inline_style( 'bianco-custom', bianco_custom_selector( '.gt-widget .tag-cloud-link', 'background-color', 'bianco_tags_widget_links_background' ) );

		wp_add_inline_style( 'bianco-custom', bianco_custom_selector( '.gt-loader .gt-sticks::before, .gt-navbar ul ul::before, .gt-footer-top::before, .gt-prevnext-article .gt-prevnext-item .gt-image::before, .gt-page-heading .gt-image .gt-image-inner::before, .gt-header > .gt-line::before, .gt-slider-top::before, .gt-slider--swiper .swiper-slide--image::before, .gt-post-list .gt-post-item .gt-image::before, .gt-page-heading::before', '', 'bianco_custom_gradient_background' ) );





		wp_add_inline_style( 'bianco-custom', bianco_custom_selector( 'html', 'font-size', 'bianco_typography_html_font_size', 'px' ) );

		wp_add_inline_style( 'bianco-custom', bianco_custom_selector( 'body', 'font-size', 'bianco_typography_body_font_size', 'rem' ) );

		wp_add_inline_style( 'bianco-custom', bianco_custom_selector( 'h1', 'font-size', 'bianco_typography_h1_font_size', 'rem' ) );

		wp_add_inline_style( 'bianco-custom', bianco_custom_selector( 'h2', 'font-size', 'bianco_typography_h2_font_size', 'rem' ) );

		wp_add_inline_style( 'bianco-custom', bianco_custom_selector( 'h3', 'font-size', 'bianco_typography_h3_font_size', 'rem' ) );

		wp_add_inline_style( 'bianco-custom', bianco_custom_selector( 'h4', 'font-size', 'bianco_typography_h4_font_size', 'rem' ) );

		wp_add_inline_style( 'bianco-custom', bianco_custom_selector( 'h5', 'font-size', 'bianco_typography_h5_font_size', 'rem' ) );

		wp_add_inline_style( 'bianco-custom', bianco_custom_selector( 'h6', 'font-size', 'bianco_typography_h6_font_size', 'rem' ) );

		wp_add_inline_style( 'bianco-custom', bianco_custom_selector( '.upload-input, .select2-dropdown, .select2-search--dropdown .select2-search__field, .select2-container--default .select2-search--dropdown .select2-search__field, .select2-container--default .select2-selection--single, #add_payment_method table.cart td.actions .coupon .input-text, .woocommerce-cart table.cart td.actions .coupon .input-text, .woocommerce-checkout table.cart td.actions .coupon .input-text, #bbpress-forums #bbp-your-profile fieldset input, #bbpress-forums #bbp-your-profile fieldset textarea, .custom-file-control, input[type="email"], input[type="number"], input[type="password"], input[type="tel"], input[type="url"], input[type="text"], input[type="time"], input[type="week"], input[type="search"], input[type="month"], input[type="datetime"], input[type="date"], textarea, textarea.form-control, select, .woocommerce form .form-row .select2-container .select2-choice, .form-control, div.cs-select, .cs-select', 'bianco_typography_input_font_size', 'rem' ) );

		wp_add_inline_style( 'bianco-custom', bianco_custom_selector( '.woocommerce #respond input#submit.alt, .woocommerce a.button.alt, .woocommerce button.button.alt, .woocommerce input.button.alt, .woocommerce #respond input#submit, .woocommerce a.button, .woocommerce button.button, .woocommerce input.button, button, input[type="button"], input[type="submit"], input[type="reset"]', 'font-size', 'bianco_typography_button_font_size', 'rem' ) );

		wp_add_inline_style( 'bianco-custom', bianco_custom_selector( '.single-post .gt-page-content', 'font-size', 'bianco_typography_post_content_font_size', 'rem' ) );

		wp_add_inline_style( 'bianco-custom', bianco_custom_selector( '.page .gt-page-content', 'font-size', 'bianco_typography_page_content_font_size', 'rem' ) );
	}
	add_action( 'wp_enqueue_scripts', 'bianco_custom_selectors' );